@@ -25,7 +25,6 @@ except ImportError:
             "cairo backend requires that pycairo>=1.14.0 or cairocffi "
             "is installed") from err
 
-import matplotlib as mpl
 from .. import _api, cbook, font_manager
 from matplotlib.backend_bases import (
     _Backend, FigureCanvasBase, FigureManagerBase, GraphicsContextBase,
@@ -101,15 +100,6 @@ class RendererCairo(RendererBase):
         self.gc.ctx = ctx
         self.width, self.height = size
 
-    @_api.deprecated("3.6", alternative="set_context")
-    def set_ctx_from_surface(self, surface):
-        self.gc.ctx = cairo.Context(surface)
-
-    @_api.deprecated("3.6")
-    def set_width_height(self, width, height):
-        self.width = width
-        self.height = height
-
     def _fill_and_stroke(self, ctx, fill_c, alpha, alpha_overrides):
         if fill_c is not None:
             ctx.save()
@@ -213,9 +203,7 @@ class RendererCairo(RendererBase):
             ctx.select_font_face(*_cairo_font_args_from_font_prop(prop))
             ctx.set_font_size(self.points_to_pixels(prop.get_size_in_points()))
             opts = cairo.FontOptions()
-            opts.set_antialias(
-                cairo.ANTIALIAS_DEFAULT if mpl.rcParams["text.antialiased"]
-                else cairo.ANTIALIAS_NONE)
+            opts.set_antialias(gc.get_antialiased())
             ctx.set_font_options(opts)
             if angle:
                 ctx.rotate(np.deg2rad(-angle))
@@ -321,6 +309,9 @@ class GraphicsContextCairo(GraphicsContextBase):
         self.ctx.set_antialias(
             cairo.ANTIALIAS_DEFAULT if b else cairo.ANTIALIAS_NONE)
 
+    def get_antialiased(self):
+        return self.ctx.get_antialias()
+
     def set_capstyle(self, cs):
         self.ctx.set_line_cap(_api.check_getitem(self._capd, capstyle=cs))
         self._capstyle = cs
@@ -478,7 +469,7 @@ class FigureCanvasCairo(FigureCanvasBase):
                     fobj = gzip.GzipFile(None, 'wb', fileobj=fobj)
             surface = cairo.SVGSurface(fobj, width_in_points, height_in_points)
         else:
-            raise ValueError("Unknown format: {!r}".format(fmt))
+            raise ValueError(f"Unknown format: {fmt!r}")
 
         self._renderer.dpi = self.figure.dpi
         self._renderer.set_context(cairo.Context(surface))
@@ -502,19 +493,6 @@ class FigureCanvasCairo(FigureCanvasBase):
     print_svgz = functools.partialmethod(_save, "svgz")
 
 
-@_api.deprecated("3.6")
-class _RendererGTKCairo(RendererCairo):
-    def set_context(self, ctx):
-        if (cairo.__name__ == "cairocffi"
-                and not isinstance(ctx, cairo.Context)):
-            ctx = cairo.Context._from_pointer(
-                cairo.ffi.cast(
-                    'cairo_t **',
-                    id(ctx) + object.__basicsize__)[0],
-                incref=True)
-        self.gc.ctx = ctx
-
-
 @_Backend.export
 class _BackendCairo(_Backend):
     backend_version = cairo.version
