@@ -1,10 +1,11 @@
 import numpy as np
 
-from matplotlib.backends.backend_agg import RendererAgg
-from matplotlib.tight_bbox import process_figure_for_rasterizing
+from matplotlib import cbook
+from .backend_agg import RendererAgg
+from matplotlib._tight_bbox import process_figure_for_rasterizing
 
 
-class MixedModeRenderer(object):
+class MixedModeRenderer:
     """
     A helper class to implement a renderer that switches between
     vector and raster drawing.  An example may be a PDF writer, where
@@ -18,24 +19,19 @@ class MixedModeRenderer(object):
         """
         Parameters
         ----------
-        figure : `matplotlib.figure.Figure`
+        figure : `~matplotlib.figure.Figure`
             The figure instance.
-
         width : scalar
             The width of the canvas in logical units
-
         height : scalar
             The height of the canvas in logical units
-
-        dpi : scalar
+        dpi : float
             The dpi of the canvas
-
-        vector_renderer : `matplotlib.backend_bases.RendererBase`
+        vector_renderer : `~matplotlib.backend_bases.RendererBase`
             An instance of a subclass of
             `~matplotlib.backend_bases.RendererBase` that will be used for the
             vector drawing.
-
-        raster_renderer_class : `matplotlib.backend_bases.RendererBase`
+        raster_renderer_class : `~matplotlib.backend_bases.RendererBase`
             The renderer class to use for the raster drawing.  If not provided,
             this will use the Agg backend (which is currently the only viable
             option anyway.)
@@ -52,13 +48,12 @@ class MixedModeRenderer(object):
         self._vector_renderer = vector_renderer
 
         self._raster_renderer = None
-        self._rasterizing = 0
 
         # A reference to the figure is needed as we need to change
         # the figure dpi before and after the rasterization. Although
         # this looks ugly, I couldn't find a better solution. -JJL
         self.figure = figure
-        self._figdpi = figure.get_dpi()
+        self._figdpi = figure.dpi
 
         self._bbox_inches_restore = bbox_inches_restore
 
@@ -76,61 +71,46 @@ class MixedModeRenderer(object):
     def start_rasterizing(self):
         """
         Enter "raster" mode.  All subsequent drawing commands (until
-        stop_rasterizing is called) will be drawn with the raster
-        backend.
-
-        If start_rasterizing is called multiple times before
-        stop_rasterizing is called, this method has no effect.
+        `stop_rasterizing` is called) will be drawn with the raster backend.
         """
-
         # change the dpi of the figure temporarily.
-        self.figure.set_dpi(self.dpi)
-
+        self.figure.dpi = self.dpi
         if self._bbox_inches_restore:  # when tight bbox is used
             r = process_figure_for_rasterizing(self.figure,
                                                self._bbox_inches_restore)
             self._bbox_inches_restore = r
 
-        if self._rasterizing == 0:
-            self._raster_renderer = self._raster_renderer_class(
-                self._width*self.dpi, self._height*self.dpi, self.dpi)
-            self._renderer = self._raster_renderer
-        self._rasterizing += 1
+        self._raster_renderer = self._raster_renderer_class(
+            self._width*self.dpi, self._height*self.dpi, self.dpi)
+        self._renderer = self._raster_renderer
 
     def stop_rasterizing(self):
         """
         Exit "raster" mode.  All of the drawing that was done since
-        the last start_rasterizing command will be copied to the
+        the last `start_rasterizing` call will be copied to the
         vector backend by calling draw_image.
-
-        If stop_rasterizing is called multiple times before
-        start_rasterizing is called, this method has no effect.
         """
-        self._rasterizing -= 1
-        if self._rasterizing == 0:
-            self._renderer = self._vector_renderer
 
-            height = self._height * self.dpi
-            buffer, bounds = self._raster_renderer.tostring_rgba_minimized()
-            l, b, w, h = bounds
-            if w > 0 and h > 0:
-                image = np.frombuffer(buffer, dtype=np.uint8)
-                image = image.reshape((h, w, 4))
-                image = image[::-1]
-                gc = self._renderer.new_gc()
-                # TODO: If the mixedmode resolution differs from the figure's
-                #       dpi, the image must be scaled (dpi->_figdpi). Not all
-                #       backends support this.
-                self._renderer.draw_image(
-                    gc,
-                    l * self._figdpi / self.dpi,
-                    (height-b-h) * self._figdpi / self.dpi,
-                    image)
-            self._raster_renderer = None
-            self._rasterizing = False
+        self._renderer = self._vector_renderer
 
-            # restore the figure dpi.
-            self.figure.set_dpi(self._figdpi)
+        height = self._height * self.dpi
+        img = np.asarray(self._raster_renderer.buffer_rgba())
+        slice_y, slice_x = cbook._get_nonzero_slices(img[..., 3])
+        cropped_img = img[slice_y, slice_x]
+        if cropped_img.size:
+            gc = self._renderer.new_gc()
+            # TODO: If the mixedmode resolution differs from the figure's
+            #       dpi, the image must be scaled (dpi->_figdpi). Not all
+            #       backends support this.
+            self._renderer.draw_image(
+                gc,
+                slice_x.start * self._figdpi / self.dpi,
+                (height - slice_y.stop) * self._figdpi / self.dpi,
+                cropped_img[::-1])
+        self._raster_renderer = None
+
+        # restore the figure dpi.
+        self.figure.dpi = self._figdpi
 
         if self._bbox_inches_restore:  # when tight bbox is used
             r = process_figure_for_rasterizing(self.figure,
