@@ -63,9 +63,10 @@ class PolarTransform(mtransforms.Transform):
         return self._scale_transform.transform(
             (0, self._axis.get_rorigin()))[1]
 
-    def transform_non_affine(self, tr):
+    @_api.rename_parameter("3.8", "tr", "values")
+    def transform_non_affine(self, values):
         # docstring inherited
-        theta, r = np.transpose(tr)
+        theta, r = np.transpose(values)
         # PolarAxes does not use the theta transforms here, but apply them for
         # backwards-compatibility if not being used by it.
         if self._apply_theta_transforms and self._axis is not None:
@@ -120,7 +121,7 @@ class PolarTransform(mtransforms.Transform):
                         codes.extend(arc.codes[1:])
                 else:  # Interpolate.
                     trs = cbook.simple_linear_interpolation(
-                        np.row_stack([(last_t, last_r), trs]),
+                        np.vstack([(last_t, last_r), trs]),
                         path._interpolation_steps)[1:]
                     xys.extend(self.transform_non_affine(trs))
                     codes.extend([Path.LINETO] * len(trs))
@@ -214,9 +215,10 @@ class InvertedPolarTransform(mtransforms.Transform):
         use_rmin="_use_rmin",
         _apply_theta_transforms="_apply_theta_transforms")
 
-    def transform_non_affine(self, xy):
+    @_api.rename_parameter("3.8", "xy", "values")
+    def transform_non_affine(self, values):
         # docstring inherited
-        x, y = xy.T
+        x, y = values.T
         r = np.hypot(x, y)
         theta = (np.arctan2(y, x) + 2 * np.pi) % (2 * np.pi)
         # PolarAxes does not use the theta transforms here, but apply them for
@@ -250,8 +252,7 @@ class ThetaFormatter(mticker.Formatter):
         # correctly with any arbitrary font (assuming it has a degree sign),
         # whereas $5\circ$ will only work correctly with one of the supported
         # math fonts (Computer Modern and STIX).
-        return ("{value:0.{digits:d}f}\N{DEGREE SIGN}"
-                .format(value=np.rad2deg(x), digits=digits))
+        return f"{np.rad2deg(x):0.{digits:d}f}\N{DEGREE SIGN}"
 
 
 class _AxisWrapper:
@@ -297,7 +298,7 @@ class ThetaLocator(mticker.Locator):
     def __call__(self):
         lim = self.axis.get_view_interval()
         if _is_full_circle_deg(lim[0], lim[1]):
-            return np.arange(8) * 2 * np.pi / 8
+            return np.deg2rad(min(lim)) + np.arange(8) * 2 * np.pi / 8
         else:
             return np.deg2rad(self.base())
 
@@ -845,11 +846,9 @@ class PolarAxes(Axes):
 
     def _init_axis(self):
         # This is moved out of __init__ because non-separable axes don't use it
-        self.xaxis = ThetaAxis(self)
-        self.yaxis = RadialAxis(self)
-        # Calling polar_axes.xaxis.clear() or polar_axes.yaxis.clear()
-        # results in weird artifacts. Therefore we disable this for now.
-        # self.spines['polar'].register_axis(self.yaxis)
+        self.xaxis = ThetaAxis(self, clear=False)
+        self.yaxis = RadialAxis(self, clear=False)
+        self.spines['polar'].register_axis(self.yaxis)
 
     def _set_lim_and_transforms(self):
         # A view limit where the minimum radius can be locked if the user
@@ -1229,8 +1228,8 @@ class PolarAxes(Axes):
     def get_rsign(self):
         return np.sign(self._originViewLim.y1 - self._originViewLim.y0)
 
-    @_api.make_keyword_only("3.6", "emit")
-    def set_rlim(self, bottom=None, top=None, emit=True, auto=False, **kwargs):
+    def set_rlim(self, bottom=None, top=None, *,
+                 emit=True, auto=False, **kwargs):
         """
         Set the radial axis view limits.
 
