@@ -1,9 +1,11 @@
+from collections.abc import MutableMapping
+import functools
+
 import numpy as np
 
-import matplotlib
-from matplotlib import cbook, docstring, rcParams
+import matplotlib as mpl
+from matplotlib import _api, _docstring
 from matplotlib.artist import allow_rasterization
-import matplotlib.cbook as cbook
 import matplotlib.transforms as mtransforms
 import matplotlib.patches as mpatches
 import matplotlib.path as mpath
@@ -11,29 +13,26 @@ import matplotlib.path as mpath
 
 class Spine(mpatches.Patch):
     """
-    An axis spine -- the line noting the data area boundaries
+    An axis spine -- the line noting the data area boundaries.
 
     Spines are the lines connecting the axis tick marks and noting the
     boundaries of the data area. They can be placed at arbitrary
-    positions. See function:`~matplotlib.spines.Spine.set_position`
-    for more information.
+    positions. See `~.Spine.set_position` for more information.
 
-    The default position is ``('outward',0)``.
+    The default position is ``('outward', 0)``.
 
-    Spines are subclasses of class:`~matplotlib.patches.Patch`, and
-    inherit much of their behavior.
+    Spines are subclasses of `.Patch`, and inherit much of their behavior.
 
-    Spines draw a line, a circle, or an arc depending if
-    function:`~matplotlib.spines.Spine.set_patch_line`,
-    function:`~matplotlib.spines.Spine.set_patch_circle`, or
-    function:`~matplotlib.spines.Spine.set_patch_arc` has been called.
-    Line-like is the default.
+    Spines draw a line, a circle, or an arc depending on if
+    `~.Spine.set_patch_line`, `~.Spine.set_patch_circle`, or
+    `~.Spine.set_patch_arc` has been called. Line-like is the default.
 
+    For examples see :ref:`spines_examples`.
     """
     def __str__(self):
         return "Spine"
 
-    @docstring.dedent_interpd
+    @_docstring.dedent_interpd
     def __init__(self, axes, spine_type, path, **kwargs):
         """
         Parameters
@@ -50,15 +49,15 @@ class Spine(mpatches.Patch):
         **kwargs
             Valid keyword arguments are:
 
-            %(Patch)s
+            %(Patch:kwdoc)s
         """
         super().__init__(**kwargs)
         self.axes = axes
         self.set_figure(self.axes.figure)
         self.spine_type = spine_type
         self.set_facecolor('none')
-        self.set_edgecolor(rcParams['axes.edgecolor'])
-        self.set_linewidth(rcParams['axes.linewidth'])
+        self.set_edgecolor(mpl.rcParams['axes.edgecolor'])
+        self.set_linewidth(mpl.rcParams['axes.linewidth'])
         self.set_capstyle('projecting')
         self.axis = None
 
@@ -66,13 +65,12 @@ class Spine(mpatches.Patch):
         self.set_transform(self.axes.transData)  # default transform
 
         self._bounds = None  # default bounds
-        self._smart_bounds = False  # deprecated in 3.2
 
         # Defer initial position determination. (Not much support for
         # non-rectangular axes is currently implemented, and this lets
         # them pass through the spines machinery without errors.)
         self._position = None
-        cbook._check_isinstance(matplotlib.path.Path, path=path)
+        _api.check_isinstance(mpath.Path, path=path)
         self._path = path
 
         # To support drawing both linear and circular spines, this
@@ -87,23 +85,6 @@ class Spine(mpatches.Patch):
         # Note: This cannot be calculated until this is added to an Axes
         self._patch_transform = mtransforms.IdentityTransform()
 
-    @cbook.deprecated("3.2")
-    def set_smart_bounds(self, value):
-        """Set the spine and associated axis to have smart bounds."""
-        self._smart_bounds = value
-
-        # also set the axis if possible
-        if self.spine_type in ('left', 'right'):
-            self.axes.yaxis.set_smart_bounds(value)
-        elif self.spine_type in ('top', 'bottom'):
-            self.axes.xaxis.set_smart_bounds(value)
-        self.stale = True
-
-    @cbook.deprecated("3.2")
-    def get_smart_bounds(self):
-        """Return whether the spine has smart bounds."""
-        return self._smart_bounds
-
     def set_patch_arc(self, center, radius, theta1, theta2):
         """Set the spine to be arc-like."""
         self._patch_type = 'arc'
@@ -171,15 +152,16 @@ class Spine(mpatches.Patch):
         # make sure the location is updated so that transforms etc are correct:
         self._adjust_location()
         bb = super().get_window_extent(renderer=renderer)
-        if self.axis is None:
+        if self.axis is None or not self.axis.get_visible():
             return bb
         bboxes = [bb]
-        tickstocheck = [self.axis.majorTicks[0]]
-        if len(self.axis.minorTicks) > 1:
-            # only pad for minor ticks if there are more than one
-            # of them.  There is always one...
-            tickstocheck.append(self.axis.minorTicks[1])
-        for tick in tickstocheck:
+        drawn_ticks = self.axis._update_ticks()
+
+        major_tick = next(iter({*drawn_ticks} & {*self.axis.majorTicks}), None)
+        minor_tick = next(iter({*drawn_ticks} & {*self.axis.minorTicks}), None)
+        for tick in [major_tick, minor_tick]:
+            if tick is None:
+                continue
             bb0 = bb.frozen()
             tickl = tick._size
             tickdir = tick._tickdir
@@ -224,44 +206,30 @@ class Spine(mpatches.Patch):
             self.set_position(self._position)
 
     def register_axis(self, axis):
-        """Register an axis.
+        """
+        Register an axis.
 
         An axis should be registered with its corresponding spine from
         the Axes instance. This allows the spine to clear any axis
         properties when needed.
         """
         self.axis = axis
-        if self.axis is not None:
-            self.axis.cla()
         self.stale = True
 
-    def cla(self):
+    def clear(self):
         """Clear the current spine."""
-        self._position = None  # clear position
+        self._clear()
         if self.axis is not None:
-            self.axis.cla()
+            self.axis.clear()
 
-    @cbook.deprecated("3.1")
-    def is_frame_like(self):
-        """Return True if directly on axes frame.
-
-        This is useful for determining if a spine is the edge of an
-        old style MPL plot. If so, this function will return True.
+    def _clear(self):
         """
-        self._ensure_position_is_set()
-        position = self._position
-        if isinstance(position, str):
-            if position == 'center':
-                position = ('axes', 0.5)
-            elif position == 'zero':
-                position = ('data', 0)
-        if len(position) != 2:
-            raise ValueError("position should be 2-tuple")
-        position_type, amount = position
-        if position_type == 'outward' and amount == 0:
-            return True
-        else:
-            return False
+        Clear things directly related to the spine.
+
+        In this way it is possible to avoid clearing the Axis as well when calling
+        from library code where it is known that the Axis is cleared separately.
+        """
+        self._position = None  # clear position
 
     def _adjust_location(self):
         """Automatically set spine bounds to the view interval."""
@@ -269,64 +237,14 @@ class Spine(mpatches.Patch):
         if self.spine_type == 'circle':
             return
 
-        if self._bounds is None:
-            if self.spine_type in ('left', 'right'):
-                low, high = self.axes.viewLim.intervaly
-            elif self.spine_type in ('top', 'bottom'):
-                low, high = self.axes.viewLim.intervalx
-            else:
-                raise ValueError('unknown spine spine_type: %s' %
-                                 self.spine_type)
-
-            if self._smart_bounds:  # deprecated in 3.2
-                # attempt to set bounds in sophisticated way
-
-                # handle inverted limits
-                viewlim_low, viewlim_high = sorted([low, high])
-
-                if self.spine_type in ('left', 'right'):
-                    datalim_low, datalim_high = self.axes.dataLim.intervaly
-                    ticks = self.axes.get_yticks()
-                elif self.spine_type in ('top', 'bottom'):
-                    datalim_low, datalim_high = self.axes.dataLim.intervalx
-                    ticks = self.axes.get_xticks()
-                # handle inverted limits
-                ticks = np.sort(ticks)
-                datalim_low, datalim_high = sorted([datalim_low, datalim_high])
-
-                if datalim_low < viewlim_low:
-                    # Data extends past view. Clip line to view.
-                    low = viewlim_low
-                else:
-                    # Data ends before view ends.
-                    cond = (ticks <= datalim_low) & (ticks >= viewlim_low)
-                    tickvals = ticks[cond]
-                    if len(tickvals):
-                        # A tick is less than or equal to lowest data point.
-                        low = tickvals[-1]
-                    else:
-                        # No tick is available
-                        low = datalim_low
-                    low = max(low, viewlim_low)
-
-                if datalim_high > viewlim_high:
-                    # Data extends past view. Clip line to view.
-                    high = viewlim_high
-                else:
-                    # Data ends before view ends.
-                    cond = (ticks >= datalim_high) & (ticks <= viewlim_high)
-                    tickvals = ticks[cond]
-                    if len(tickvals):
-                        # A tick is greater than or equal to highest data
-                        # point.
-                        high = tickvals[0]
-                    else:
-                        # No tick is available
-                        high = datalim_high
-                    high = min(high, viewlim_high)
-
-        else:
+        if self._bounds is not None:
             low, high = self._bounds
+        elif self.spine_type in ('left', 'right'):
+            low, high = self.axes.viewLim.intervaly
+        elif self.spine_type in ('top', 'bottom'):
+            low, high = self.axes.viewLim.intervalx
+        else:
+            raise ValueError(f'unknown spine spine_type: {self.spine_type}')
 
         if self._patch_type == 'arc':
             if self.spine_type in ('bottom', 'top'):
@@ -379,28 +297,27 @@ class Spine(mpatches.Patch):
         return ret
 
     def set_position(self, position):
-        """Set the position of the spine.
+        """
+        Set the position of the spine.
 
         Spine position is specified by a 2 tuple of (position type,
         amount). The position types are:
 
-        * 'outward' : place the spine out from the data area by the
-          specified number of points. (Negative values specify placing the
-          spine inward.)
-
-        * 'axes' : place the spine at the specified Axes coordinate (from
-          0.0-1.0).
-
-        * 'data' : place the spine at the specified data coordinate.
+        * 'outward': place the spine out from the data area by the specified
+          number of points. (Negative values place the spine inwards.)
+        * 'axes': place the spine at the specified Axes coordinate (0 to 1).
+        * 'data': place the spine at the specified data coordinate.
 
         Additionally, shorthand notations define a special positions:
 
-        * 'center' -> ('axes',0.5)
-        * 'zero' -> ('data', 0.0)
+        * 'center' -> ``('axes', 0.5)``
+        * 'zero' -> ``('data', 0.0)``
 
+        Examples
+        --------
+        :doc:`/gallery/spines/spine_placement_demo`
         """
-        if position in ('center', 'zero'):
-            # special positions
+        if position in ('center', 'zero'):  # special positions
             pass
         else:
             if len(position) != 2:
@@ -409,9 +326,7 @@ class Spine(mpatches.Patch):
                 raise ValueError("position[0] should be one of 'outward', "
                                  "'axes', or 'data' ")
         self._position = position
-
         self.set_transform(self.get_spine_transform())
-
         if self.axis is not None:
             self.axis.reset_ticks()
         self.stale = True
@@ -433,8 +348,8 @@ class Spine(mpatches.Patch):
                 position = ('data', 0)
         assert len(position) == 2, 'position should be 2-tuple'
         position_type, amount = position
-        cbook._check_in_list(['axes', 'outward', 'data'],
-                             position_type=position_type)
+        _api.check_in_list(['axes', 'outward', 'data'],
+                           position_type=position_type)
         if self.spine_type in ['left', 'right']:
             base_transform = self.axes.get_yaxis_transform(which='grid')
         elif self.spine_type in ['top', 'bottom']:
@@ -516,9 +431,7 @@ class Spine(mpatches.Patch):
 
     @classmethod
     def linear_spine(cls, axes, spine_type, **kwargs):
-        """
-        Returns a linear `Spine`.
-        """
+        """Create and return a linear `Spine`."""
         # all values of 0.999 get replaced upon call to set_bounds()
         if spine_type == 'left':
             path = mpath.Path([(0.0, 0.999), (0.0, 0.999)])
@@ -531,16 +444,14 @@ class Spine(mpatches.Patch):
         else:
             raise ValueError('unable to make path for spine "%s"' % spine_type)
         result = cls(axes, spine_type, path, **kwargs)
-        result.set_visible(rcParams['axes.spines.{0}'.format(spine_type)])
+        result.set_visible(mpl.rcParams[f'axes.spines.{spine_type}'])
 
         return result
 
     @classmethod
     def arc_spine(cls, axes, spine_type, center, radius, theta1, theta2,
                   **kwargs):
-        """
-        Returns an arc `Spine`.
-        """
+        """Create and return an arc `Spine`."""
         path = mpath.Path.arc(theta1, theta2)
         result = cls(axes, spine_type, path, **kwargs)
         result.set_patch_arc(center, radius, theta1, theta2)
@@ -548,9 +459,7 @@ class Spine(mpatches.Patch):
 
     @classmethod
     def circular_spine(cls, axes, center, radius, **kwargs):
-        """
-        Returns a circular `Spine`.
-        """
+        """Create and return a circular `Spine`."""
         path = mpath.Path.unit_circle()
         spine_type = 'circle'
         result = cls(axes, spine_type, path, **kwargs)
@@ -568,8 +477,119 @@ class Spine(mpatches.Patch):
         Notes
         -----
         This method does not modify the facecolor (which defaults to "none"),
-        unlike the `Patch.set_color` method defined in the parent class.  Use
-        `Patch.set_facecolor` to set the facecolor.
+        unlike the `.Patch.set_color` method defined in the parent class.  Use
+        `.Patch.set_facecolor` to set the facecolor.
         """
         self.set_edgecolor(c)
         self.stale = True
+
+
+class SpinesProxy:
+    """
+    A proxy to broadcast ``set_*()`` and ``set()`` method calls to contained `.Spines`.
+
+    The proxy cannot be used for any other operations on its members.
+
+    The supported methods are determined dynamically based on the contained
+    spines. If not all spines support a given method, it's executed only on
+    the subset of spines that support it.
+    """
+    def __init__(self, spine_dict):
+        self._spine_dict = spine_dict
+
+    def __getattr__(self, name):
+        broadcast_targets = [spine for spine in self._spine_dict.values()
+                             if hasattr(spine, name)]
+        if (name != 'set' and not name.startswith('set_')) or not broadcast_targets:
+            raise AttributeError(
+                f"'SpinesProxy' object has no attribute '{name}'")
+
+        def x(_targets, _funcname, *args, **kwargs):
+            for spine in _targets:
+                getattr(spine, _funcname)(*args, **kwargs)
+        x = functools.partial(x, broadcast_targets, name)
+        x.__doc__ = broadcast_targets[0].__doc__
+        return x
+
+    def __dir__(self):
+        names = []
+        for spine in self._spine_dict.values():
+            names.extend(name
+                         for name in dir(spine) if name.startswith('set_'))
+        return list(sorted(set(names)))
+
+
+class Spines(MutableMapping):
+    r"""
+    The container of all `.Spine`\s in an Axes.
+
+    The interface is dict-like mapping names (e.g. 'left') to `.Spine` objects.
+    Additionally, it implements some pandas.Series-like features like accessing
+    elements by attribute::
+
+        spines['top'].set_visible(False)
+        spines.top.set_visible(False)
+
+    Multiple spines can be addressed simultaneously by passing a list::
+
+        spines[['top', 'right']].set_visible(False)
+
+    Use an open slice to address all spines::
+
+        spines[:].set_visible(False)
+
+    The latter two indexing methods will return a `SpinesProxy` that broadcasts all
+    ``set_*()`` and ``set()`` calls to its members, but cannot be used for any other
+    operation.
+    """
+    def __init__(self, **kwargs):
+        self._dict = kwargs
+
+    @classmethod
+    def from_dict(cls, d):
+        return cls(**d)
+
+    def __getstate__(self):
+        return self._dict
+
+    def __setstate__(self, state):
+        self.__init__(**state)
+
+    def __getattr__(self, name):
+        try:
+            return self._dict[name]
+        except KeyError:
+            raise AttributeError(
+                f"'Spines' object does not contain a '{name}' spine")
+
+    def __getitem__(self, key):
+        if isinstance(key, list):
+            unknown_keys = [k for k in key if k not in self._dict]
+            if unknown_keys:
+                raise KeyError(', '.join(unknown_keys))
+            return SpinesProxy({k: v for k, v in self._dict.items()
+                                if k in key})
+        if isinstance(key, tuple):
+            raise ValueError('Multiple spines must be passed as a single list')
+        if isinstance(key, slice):
+            if key.start is None and key.stop is None and key.step is None:
+                return SpinesProxy(self._dict)
+            else:
+                raise ValueError(
+                    'Spines does not support slicing except for the fully '
+                    'open slice [:] to access all spines.')
+        return self._dict[key]
+
+    def __setitem__(self, key, value):
+        # TODO: Do we want to deprecate adding spines?
+        self._dict[key] = value
+
+    def __delitem__(self, key):
+        # TODO: Do we want to deprecate deleting spines?
+        del self._dict[key]
+
+    def __iter__(self):
+        return iter(self._dict)
+
+    def __len__(self):
+        return len(self._dict)
