@@ -16,6 +16,7 @@ import matplotlib as mpl
 from matplotlib import gridspec
 from matplotlib.testing.decorators import image_comparison, check_figures_equal
 from matplotlib.axes import Axes
+from matplotlib.backend_bases import KeyEvent, MouseEvent
 from matplotlib.figure import Figure, FigureBase
 from matplotlib.layout_engine import (ConstrainedLayoutEngine,
                                       TightLayoutEngine,
@@ -287,6 +288,33 @@ def test_suptitle_fontproperties():
     assert txt.get_weight() == fps.get_weight()
 
 
+def test_suptitle_subfigures():
+    fig = plt.figure(figsize=(4, 3))
+    sf1, sf2 = fig.subfigures(1, 2)
+    sf2.set_facecolor('white')
+    sf1.subplots()
+    sf2.subplots()
+    fig.suptitle("This is a visible suptitle.")
+
+    # verify the first subfigure facecolor is the default transparent
+    assert sf1.get_facecolor() == (0.0, 0.0, 0.0, 0.0)
+    # verify the second subfigure facecolor is white
+    assert sf2.get_facecolor() == (1.0, 1.0, 1.0, 1.0)
+
+
+def test_get_suptitle_supxlabel_supylabel():
+    fig, ax = plt.subplots()
+    assert fig.get_suptitle() == ""
+    assert fig.get_supxlabel() == ""
+    assert fig.get_supylabel() == ""
+    fig.suptitle('suptitle')
+    assert fig.get_suptitle() == 'suptitle'
+    fig.supxlabel('supxlabel')
+    assert fig.get_supxlabel() == 'supxlabel'
+    fig.supylabel('supylabel')
+    assert fig.get_supylabel() == 'supylabel'
+
+
 @image_comparison(['alpha_background'],
                   # only test png and svg. The PDF output appears correct,
                   # but Ghostscript does not preserve the background color.
@@ -457,12 +485,21 @@ def test_invalid_figure_add_axes():
     with pytest.raises(TypeError, match="multiple values for argument 'rect'"):
         fig.add_axes([0, 0, 1, 1], rect=[0, 0, 1, 1])
 
-    _, ax = plt.subplots()
+    fig2, ax = plt.subplots()
     with pytest.raises(ValueError,
                        match="The Axes must have been created in the present "
                              "figure"):
         fig.add_axes(ax)
 
+    fig2.delaxes(ax)
+    with pytest.warns(mpl.MatplotlibDeprecationWarning,
+                      match="Passing more than one positional argument"):
+        fig2.add_axes(ax, "extra positional argument")
+
+    with pytest.warns(mpl.MatplotlibDeprecationWarning,
+                      match="Passing more than one positional argument"):
+        fig.add_axes([0, 0, 1, 1], "extra positional argument")
+
 
 def test_subplots_shareax_loglabels():
     fig, axs = plt.subplots(2, 2, sharex=True, sharey=True, squeeze=False)
@@ -550,6 +587,29 @@ def test_savefig_locate_colorbar():
             cbar.ax.get_position(original=False).bounds)
 
 
+@mpl.rc_context({"savefig.transparent": True})
+@check_figures_equal(extensions=["png"])
+def test_savefig_transparent(fig_test, fig_ref):
+    # create two transparent subfigures with corresponding transparent inset
+    # axes. the entire background of the image should be transparent.
+    gs1 = fig_test.add_gridspec(3, 3, left=0.05, wspace=0.05)
+    f1 = fig_test.add_subfigure(gs1[:, :])
+    f2 = f1.add_subfigure(gs1[0, 0])
+
+    ax12 = f2.add_subplot(gs1[:, :])
+
+    ax1 = f1.add_subplot(gs1[:-1, :])
+    iax1 = ax1.inset_axes([.1, .2, .3, .4])
+    iax2 = iax1.inset_axes([.1, .2, .3, .4])
+
+    ax2 = fig_test.add_subplot(gs1[-1, :-1])
+    ax3 = fig_test.add_subplot(gs1[-1, -1])
+
+    for ax in [ax12, ax1, iax1, iax2, ax2, ax3]:
+        ax.set(xticks=[], yticks=[])
+        ax.spines[:].set_visible(False)
+
+
 def test_figure_repr():
     fig = plt.figure(figsize=(10, 20), dpi=10)
     assert repr(fig) == "<Figure size 100x200 with 0 Axes>"
@@ -680,7 +740,7 @@ def test_add_artist(fig_test, fig_ref):
 
 @pytest.mark.parametrize("fmt", ["png", "pdf", "ps", "eps", "svg"])
 def test_fspath(fmt, tmpdir):
-    out = Path(tmpdir, "test.{}".format(fmt))
+    out = Path(tmpdir, f"test.{fmt}")
     plt.savefig(out)
     with out.open("rb") as file:
         # All the supported formats include the format name (case-insensitive)
@@ -1216,12 +1276,14 @@ def test_subfigure():
         pc = ax.pcolormesh(np.random.randn(30, 30), vmin=-2, vmax=2)
     sub[0].colorbar(pc, ax=axs)
     sub[0].suptitle('Left Side')
+    sub[0].set_facecolor('white')
 
     axs = sub[1].subplots(1, 3)
     for ax in axs.flat:
         pc = ax.pcolormesh(np.random.randn(30, 30), vmin=-2, vmax=2)
     sub[1].colorbar(pc, ax=axs, location='bottom')
     sub[1].suptitle('Right Side')
+    sub[1].set_facecolor('white')
 
     fig.suptitle('Figure suptitle', fontsize='xx-large')
 
@@ -1473,19 +1535,20 @@ def test_add_axes_kwargs():
 def test_ginput(recwarn):  # recwarn undoes warn filters at exit.
     warnings.filterwarnings("ignore", "cannot show the figure")
     fig, ax = plt.subplots()
+    trans = ax.transData.transform
 
     def single_press():
-        fig.canvas.button_press_event(*ax.transData.transform((.1, .2)), 1)
+        MouseEvent("button_press_event", fig.canvas, *trans((.1, .2)), 1)._process()
 
     Timer(.1, single_press).start()
     assert fig.ginput() == [(.1, .2)]
 
     def multi_presses():
-        fig.canvas.button_press_event(*ax.transData.transform((.1, .2)), 1)
-        fig.canvas.key_press_event("backspace")
-        fig.canvas.button_press_event(*ax.transData.transform((.3, .4)), 1)
-        fig.canvas.button_press_event(*ax.transData.transform((.5, .6)), 1)
-        fig.canvas.button_press_event(*ax.transData.transform((0, 0)), 2)
+        MouseEvent("button_press_event", fig.canvas, *trans((.1, .2)), 1)._process()
+        KeyEvent("key_press_event", fig.canvas, "backspace")._process()
+        MouseEvent("button_press_event", fig.canvas, *trans((.3, .4)), 1)._process()
+        MouseEvent("button_press_event", fig.canvas, *trans((.5, .6)), 1)._process()
+        MouseEvent("button_press_event", fig.canvas, *trans((0, 0)), 2)._process()
 
     Timer(.1, multi_presses).start()
     np.testing.assert_allclose(fig.ginput(3), [(.3, .4), (.5, .6)])
@@ -1495,9 +1558,9 @@ def test_waitforbuttonpress(recwarn):  # recwarn undoes warn filters at exit.
     warnings.filterwarnings("ignore", "cannot show the figure")
     fig = plt.figure()
     assert fig.waitforbuttonpress(timeout=.1) is None
-    Timer(.1, fig.canvas.key_press_event, ("z",)).start()
+    Timer(.1, KeyEvent("key_press_event", fig.canvas, "z")._process).start()
     assert fig.waitforbuttonpress() is True
-    Timer(.1, fig.canvas.button_press_event, (0, 0, 1)).start()
+    Timer(.1, MouseEvent("button_press_event", fig.canvas, 0, 0, 1)._process).start()
     assert fig.waitforbuttonpress() is False
 
 
@@ -1564,9 +1627,35 @@ def test_gridspec_no_mutate_input():
     plt.subplot_mosaic('AB', width_ratios=[1, 2], gridspec_kw=gs)
 
 
+@pytest.mark.parametrize('fmt', ['eps', 'pdf', 'png', 'ps', 'svg', 'svgz'])
+def test_savefig_metadata(fmt):
+    Figure().savefig(io.BytesIO(), format=fmt, metadata={})
+
+
+@pytest.mark.parametrize('fmt', ['jpeg', 'jpg', 'tif', 'tiff', 'webp', "raw", "rgba"])
+def test_savefig_metadata_error(fmt):
+    with pytest.raises(ValueError, match="metadata not supported"):
+        Figure().savefig(io.BytesIO(), format=fmt, metadata={})
+
+
 def test_get_constrained_layout_pads():
     params = {'w_pad': 0.01, 'h_pad': 0.02, 'wspace': 0.03, 'hspace': 0.04}
     expected = tuple([*params.values()])
     fig = plt.figure(layout=mpl.layout_engine.ConstrainedLayoutEngine(**params))
     with pytest.warns(PendingDeprecationWarning, match="will be deprecated"):
         assert fig.get_constrained_layout_pads() == expected
+
+
+def test_not_visible_figure():
+    fig = Figure()
+
+    buf = io.StringIO()
+    fig.savefig(buf, format='svg')
+    buf.seek(0)
+    assert '<g ' in buf.read()
+
+    fig.set_visible(False)
+    buf = io.StringIO()
+    fig.savefig(buf, format='svg')
+    buf.seek(0)
+    assert '<g ' not in buf.read()
