@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 import platform
 import re
+import shutil
 import subprocess
 import sys
 import weakref
@@ -62,6 +63,8 @@ class NullMovieWriter(animation.AbstractMovieWriter):
         self._count = 0
 
     def grab_frame(self, **savefig_kwargs):
+        from matplotlib.animation import _validate_grabframe_kwargs
+        _validate_grabframe_kwargs(savefig_kwargs)
         self.savefig_kwargs = savefig_kwargs
         self._count += 1
 
@@ -193,6 +196,38 @@ def test_save_animation_smoketest(tmpdir, writer, frame_format, output, anim):
     del anim
 
 
+@pytest.mark.parametrize('writer, frame_format, output', gen_writers())
+def test_grabframe(tmpdir, writer, frame_format, output):
+    WriterClass = animation.writers[writer]
+
+    if frame_format is not None:
+        plt.rcParams["animation.frame_format"] = frame_format
+
+    fig, ax = plt.subplots()
+
+    dpi = None
+    codec = None
+    if writer == 'ffmpeg':
+        # Issue #8253
+        fig.set_size_inches((10.85, 9.21))
+        dpi = 100.
+        codec = 'h264'
+
+    test_writer = WriterClass()
+    # Use temporary directory for the file-based writers, which produce a file
+    # per frame with known names.
+    with tmpdir.as_cwd():
+        with test_writer.saving(fig, output, dpi):
+            # smoke test it works
+            test_writer.grab_frame()
+            for k in {'dpi', 'bbox_inches', 'format'}:
+                with pytest.raises(
+                        TypeError,
+                        match=f"grab_frame got an unexpected keyword argument {k!r}"
+                ):
+                    test_writer.grab_frame(**{k: object()})
+
+
 @pytest.mark.parametrize('writer', [
     pytest.param(
         'ffmpeg', marks=pytest.mark.skipif(
@@ -284,7 +319,7 @@ def test_cleanup_temporaries(method_name, tmpdir, anim):
         assert list(Path(str(tmpdir)).iterdir()) == []
 
 
-@pytest.mark.skipif(os.name != "posix", reason="requires a POSIX OS")
+@pytest.mark.skipif(shutil.which("/bin/sh") is None, reason="requires a POSIX OS")
 def test_failing_ffmpeg(tmpdir, monkeypatch, anim):
     """
     Test that we correctly raise a CalledProcessError when ffmpeg fails.
@@ -510,9 +545,9 @@ def test_disable_cache_warning(anim):
 
 def test_movie_writer_invalid_path(anim):
     if sys.platform == "win32":
-        match_str = re.escape("[WinError 3] The system cannot find the path specified:")
+        match_str = r"\[WinError 3] .*'\\\\foo\\\\bar\\\\aardvark'"
     else:
-        match_str = re.escape("[Errno 2] No such file or directory: '/foo")
+        match_str = r"\[Errno 2] .*'/foo"
     with pytest.raises(FileNotFoundError, match=match_str):
         anim.save("/foo/bar/aardvark/thiscannotreallyexist.mp4",
                   writer=animation.FFMpegFileWriter())
