@@ -54,7 +54,7 @@ def _prism_blue(x): return -1.1 * np.sin((x * 20.9) * np.pi)
 _prism_data = {'red': _prism_red, 'green': _prism_green, 'blue': _prism_blue}
 
 def _ch_helper(gamma, s, r, h, p0, p1, x):
-    """Helper function for generating picklable cubehelix color maps."""
+    """Helper function for generating picklable cubehelix colormaps."""
     # Apply gamma factor to emphasise low or high intensity values
     xg = x ** gamma
     # Calculate amplitude and angle of deviation from the black to white
@@ -65,41 +65,39 @@ def _ch_helper(gamma, s, r, h, p0, p1, x):
 
 def cubehelix(gamma=1.0, s=0.5, r=-1.5, h=1.0):
     """
-    Return custom data dictionary of (r,g,b) conversion functions, which can be
-    used with :func:`register_cmap`, for the cubehelix color scheme.
+    Return custom data dictionary of (r, g, b) conversion functions, which can
+    be used with :func:`register_cmap`, for the cubehelix color scheme.
 
     Unlike most other color schemes cubehelix was designed by D.A. Green to
     be monotonically increasing in terms of perceived brightness.
     Also, when printed on a black and white postscript printer, the scheme
     results in a greyscale with monotonically increasing brightness.
-    This color scheme is named cubehelix because the r,g,b values produced
+    This color scheme is named cubehelix because the (r, g, b) values produced
     can be visualised as a squashed helix around the diagonal in the
-    r,g,b color cube.
+    (r, g, b) color cube.
 
-    For a unit color cube (i.e. 3-D coordinates for r,g,b each in the
-    range 0 to 1) the color scheme starts at (r,g,b) = (0,0,0), i.e. black,
-    and finishes at (r,g,b) = (1,1,1), i.e. white. For some fraction *x*,
+    For a unit color cube (i.e. 3D coordinates for (r, g, b) each in the
+    range 0 to 1) the color scheme starts at (r, g, b) = (0, 0, 0), i.e. black,
+    and finishes at (r, g, b) = (1, 1, 1), i.e. white. For some fraction *x*,
     between 0 and 1, the color is the corresponding grey value at that
-    fraction along the black to white diagonal (x,x,x) plus a color
+    fraction along the black to white diagonal (x, x, x) plus a color
     element. This color element is calculated in a plane of constant
     perceived intensity and controlled by the following parameters.
 
-    Optional keyword arguments:
-
-      =========   =======================================================
-      Keyword     Description
-      =========   =======================================================
-      gamma       gamma factor to emphasise either low intensity values
-                  (gamma < 1), or high intensity values (gamma > 1);
-                  defaults to 1.0.
-      s           the start color; defaults to 0.5 (i.e. purple).
-      r           the number of r,g,b rotations in color that are made
-                  from the start to the end of the color scheme; defaults
-                  to -1.5 (i.e. -> B -> G -> R -> B).
-      h           the hue parameter which controls how saturated the
-                  colors are. If this parameter is zero then the color
-                  scheme is purely a greyscale; defaults to 1.0.
-      =========   =======================================================
+    Parameters
+    ----------
+    gamma : float, default: 1
+        Gamma factor emphasizing either low intensity values (gamma < 1), or
+        high intensity values (gamma > 1).
+    s : float, default: 0.5 (purple)
+        The starting color.
+    r : float, default: -1.5
+        The number of r, g, b rotations in color that are made from the start
+        to the end of the color scheme.  The default of -1.5 corresponds to ->
+        B -> G -> R -> B.
+    h : float, default: 1
+        The hue, i.e. how saturated the colors are. If this parameter is zero
+        then the color scheme is purely a greyscale.
     """
     return {'red': partial(_ch_helper, gamma, s, r, h, -0.14861, 1.78277),
             'green': partial(_ch_helper, gamma, s, r, h, -0.29227, -0.90649),
@@ -157,7 +155,7 @@ def _g34(x): return 2 * x
 def _g35(x): return 2 * x - 0.5
 def _g36(x): return 2 * x - 1
 
-gfunc = {i: globals()["_g{}".format(i)] for i in range(37)}
+gfunc = {i: globals()[f"_g{i}"] for i in range(37)}
 
 _gnuplot_data = {
         'red': gfunc[7],
@@ -242,12 +240,22 @@ _hsv_data = {'red':   ((0., 1., 1.),
                        (0.857143, 0.937500, 0.937500),
                        (1.0, 0.09375, 0.09375))}
 
-_jet_data = {'red':   ((0., 0, 0), (0.35, 0, 0), (0.66, 1, 1), (0.89, 1, 1),
-                         (1, 0.5, 0.5)),
-             'green': ((0., 0, 0), (0.125, 0, 0), (0.375, 1, 1), (0.64, 1, 1),
-                         (0.91, 0, 0), (1, 0, 0)),
-             'blue':  ((0., 0.5, 0.5), (0.11, 1, 1), (0.34, 1, 1),
-                         (0.65, 0, 0), (1, 0, 0))}
+_jet_data = {'red':   ((0.00, 0, 0),
+                       (0.35, 0, 0),
+                       (0.66, 1, 1),
+                       (0.89, 1, 1),
+                       (1.00, 0.5, 0.5)),
+             'green': ((0.000, 0, 0),
+                       (0.125, 0, 0),
+                       (0.375, 1, 1),
+                       (0.640, 1, 1),
+                       (0.910, 0, 0),
+                       (1.000, 0, 0)),
+             'blue':  ((0.00, 0.5, 0.5),
+                       (0.11, 1, 1),
+                       (0.34, 1, 1),
+                       (0.65, 0, 0),
+                       (1.00, 0, 0))}
 
 _pink_data = {'red':   ((0., 0.1178, 0.1178), (0.015873, 0.195857, 0.195857),
                         (0.031746, 0.250661, 0.250661),
@@ -451,44 +459,50 @@ _winter_data = {'red':   ((0., 0., 0.), (1.0, 0.0, 0.0)),
                 'blue':  ((0., 1., 1.), (1.0, 0.5, 0.5))}
 
 _nipy_spectral_data = {
-      'red': [(0.0, 0.0, 0.0), (0.05, 0.4667, 0.4667),
-              (0.10, 0.5333, 0.5333), (0.15, 0.0, 0.0),
-              (0.20, 0.0, 0.0), (0.25, 0.0, 0.0),
-              (0.30, 0.0, 0.0), (0.35, 0.0, 0.0),
-              (0.40, 0.0, 0.0), (0.45, 0.0, 0.0),
-              (0.50, 0.0, 0.0), (0.55, 0.0, 0.0),
-              (0.60, 0.0, 0.0), (0.65, 0.7333, 0.7333),
-              (0.70, 0.9333, 0.9333), (0.75, 1.0, 1.0),
-              (0.80, 1.0, 1.0), (0.85, 1.0, 1.0),
-              (0.90, 0.8667, 0.8667), (0.95, 0.80, 0.80),
-              (1.0, 0.80, 0.80)],
-    'green': [(0.0, 0.0, 0.0), (0.05, 0.0, 0.0),
-              (0.10, 0.0, 0.0), (0.15, 0.0, 0.0),
-              (0.20, 0.0, 0.0), (0.25, 0.4667, 0.4667),
-              (0.30, 0.6000, 0.6000), (0.35, 0.6667, 0.6667),
-              (0.40, 0.6667, 0.6667), (0.45, 0.6000, 0.6000),
-              (0.50, 0.7333, 0.7333), (0.55, 0.8667, 0.8667),
-              (0.60, 1.0, 1.0), (0.65, 1.0, 1.0),
-              (0.70, 0.9333, 0.9333), (0.75, 0.8000, 0.8000),
-              (0.80, 0.6000, 0.6000), (0.85, 0.0, 0.0),
-              (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
-              (1.0, 0.80, 0.80)],
-     'blue': [(0.0, 0.0, 0.0), (0.05, 0.5333, 0.5333),
-              (0.10, 0.6000, 0.6000), (0.15, 0.6667, 0.6667),
-              (0.20, 0.8667, 0.8667), (0.25, 0.8667, 0.8667),
-              (0.30, 0.8667, 0.8667), (0.35, 0.6667, 0.6667),
-              (0.40, 0.5333, 0.5333), (0.45, 0.0, 0.0),
-              (0.5, 0.0, 0.0), (0.55, 0.0, 0.0),
-              (0.60, 0.0, 0.0), (0.65, 0.0, 0.0),
-              (0.70, 0.0, 0.0), (0.75, 0.0, 0.0),
-              (0.80, 0.0, 0.0), (0.85, 0.0, 0.0),
-              (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
-              (1.0, 0.80, 0.80)],
+    'red': [
+        (0.0, 0.0, 0.0), (0.05, 0.4667, 0.4667),
+        (0.10, 0.5333, 0.5333), (0.15, 0.0, 0.0),
+        (0.20, 0.0, 0.0), (0.25, 0.0, 0.0),
+        (0.30, 0.0, 0.0), (0.35, 0.0, 0.0),
+        (0.40, 0.0, 0.0), (0.45, 0.0, 0.0),
+        (0.50, 0.0, 0.0), (0.55, 0.0, 0.0),
+        (0.60, 0.0, 0.0), (0.65, 0.7333, 0.7333),
+        (0.70, 0.9333, 0.9333), (0.75, 1.0, 1.0),
+        (0.80, 1.0, 1.0), (0.85, 1.0, 1.0),
+        (0.90, 0.8667, 0.8667), (0.95, 0.80, 0.80),
+        (1.0, 0.80, 0.80),
+    ],
+    'green': [
+        (0.0, 0.0, 0.0), (0.05, 0.0, 0.0),
+        (0.10, 0.0, 0.0), (0.15, 0.0, 0.0),
+        (0.20, 0.0, 0.0), (0.25, 0.4667, 0.4667),
+        (0.30, 0.6000, 0.6000), (0.35, 0.6667, 0.6667),
+        (0.40, 0.6667, 0.6667), (0.45, 0.6000, 0.6000),
+        (0.50, 0.7333, 0.7333), (0.55, 0.8667, 0.8667),
+        (0.60, 1.0, 1.0), (0.65, 1.0, 1.0),
+        (0.70, 0.9333, 0.9333), (0.75, 0.8000, 0.8000),
+        (0.80, 0.6000, 0.6000), (0.85, 0.0, 0.0),
+        (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
+        (1.0, 0.80, 0.80),
+    ],
+    'blue': [
+        (0.0, 0.0, 0.0), (0.05, 0.5333, 0.5333),
+        (0.10, 0.6000, 0.6000), (0.15, 0.6667, 0.6667),
+        (0.20, 0.8667, 0.8667), (0.25, 0.8667, 0.8667),
+        (0.30, 0.8667, 0.8667), (0.35, 0.6667, 0.6667),
+        (0.40, 0.5333, 0.5333), (0.45, 0.0, 0.0),
+        (0.5, 0.0, 0.0), (0.55, 0.0, 0.0),
+        (0.60, 0.0, 0.0), (0.65, 0.0, 0.0),
+        (0.70, 0.0, 0.0), (0.75, 0.0, 0.0),
+        (0.80, 0.0, 0.0), (0.85, 0.0, 0.0),
+        (0.90, 0.0, 0.0), (0.95, 0.0, 0.0),
+        (1.0, 0.80, 0.80),
+    ],
 }
 
 
 # 34 colormaps based on color specifications and designs
-# developed by Cynthia Brewer (http://colorbrewer.org).
+# developed by Cynthia Brewer (https://colorbrewer2.org/).
 # The ColorBrewer palettes have been included under the terms
 # of an Apache-stype license (for details, see the file
 # LICENSE_COLORBREWER in the license directory of the matplotlib
@@ -1088,7 +1102,7 @@ _gist_stern_data = {
 def _gist_yarg(x): return 1 - x
 _gist_yarg_data = {'red': _gist_yarg, 'green': _gist_yarg, 'blue': _gist_yarg}
 
-# This bipolar color map was generated from CoolWarmFloat33.csv of
+# This bipolar colormap was generated from CoolWarmFloat33.csv of
 # "Diverging Color Maps for Scientific Visualization" by Kenneth Moreland.
 # <http://www.kennethmoreland.com/color-maps/>
 _coolwarm_data = {
@@ -1199,8 +1213,8 @@ _coolwarm_data = {
 # Implementation of Carey Rappaport's CMRmap.
 # See `A Color Map for Effective Black-and-White Rendering of Color-Scale
 # Images' by Carey Rappaport
-# http://www.mathworks.com/matlabcentral/fileexchange/2662-cmrmap-m
-_CMRmap_data = {'red':     ((0.000, 0.00, 0.00),
+# https://www.mathworks.com/matlabcentral/fileexchange/2662-cmrmap-m
+_CMRmap_data = {'red':    ((0.000, 0.00, 0.00),
                            (0.125, 0.15, 0.15),
                            (0.250, 0.30, 0.30),
                            (0.375, 0.60, 0.60),
@@ -1231,7 +1245,7 @@ _CMRmap_data = {'red':     ((0.000, 0.00, 0.00),
 
 # An MIT licensed, colorblind-friendly heatmap from Wistia:
 #   https://github.com/wistia/heatmap-palette
-#   http://wistia.com/blog/heatmaps-for-colorblindness
+#   https://wistia.com/learn/culture/heatmaps-for-colorblindness
 #
 # >>> import matplotlib.colors as c
 # >>> colors = ["#e4ff7a", "#ffe81a", "#ffbd00", "#ffa000", "#fc7f00"]
