@@ -7,7 +7,12 @@
 #    Copyright The Matplotlib development team
 
 """
-This module provides functionality to add a table to a plot.
+Tables drawing.
+
+.. note::
+    The table implementation in Matplotlib is lightly maintained. For a more
+    featureful table implementation, you may wish to try `blume
+    <https://github.com/swfiua/blume>`_.
 
 Use the factory function `~matplotlib.table.table` to create a ready-made
 table from texts. If you need more control, use the `.Table` class and its
@@ -19,7 +24,9 @@ The cell (0, 0) is positioned at the top left.
 Thanks to John Gill for providing the class and table.
 """
 
-from . import artist, cbook, docstring
+import numpy as np
+
+from . import _api, _docstring
 from .artist import Artist, allow_rasterization
 from .patches import Rectangle
 from .text import Text
@@ -31,65 +38,80 @@ class Cell(Rectangle):
     """
     A cell is a `.Rectangle` with some associated `.Text`.
 
-    .. note:
-        As a user, you'll most likely not creates cells yourself. Instead, you
-        should use either the `~matplotlib.table.table` factory function or
-        `.Table.add_cell`.
-
-    Parameters
-    ----------
-    xy : 2-tuple
-        The position of the bottom left corner of the cell.
-    width : float
-        The cell width.
-    height : float
-        The cell height.
-    edgecolor : color
-        The color of the cell border.
-    facecolor : color
-        The cell facecolor.
-    fill : bool
-        Whether the cell background is filled.
-    text : str
-        The cell text.
-    loc : {'left', 'center', 'right'}, default: 'right'
-        The alignment of the text within the cell.
-    fontproperties : dict
-        A dict defining the font properties of the text. Supported keys and
-        values are the keyword arguments accepted by `.FontProperties`.
+    As a user, you'll most likely not creates cells yourself. Instead, you
+    should use either the `~matplotlib.table.table` factory function or
+    `.Table.add_cell`.
     """
 
     PAD = 0.1
     """Padding between text and rectangle."""
 
-    def __init__(self, xy, width, height,
+    _edges = 'BRTL'
+    _edge_aliases = {'open':         '',
+                     'closed':       _edges,  # default
+                     'horizontal':   'BT',
+                     'vertical':     'RL'
+                     }
+
+    def __init__(self, xy, width, height, *,
                  edgecolor='k', facecolor='w',
                  fill=True,
                  text='',
                  loc=None,
-                 fontproperties=None
+                 fontproperties=None,
+                 visible_edges='closed',
                  ):
+        """
+        Parameters
+        ----------
+        xy : 2-tuple
+            The position of the bottom left corner of the cell.
+        width : float
+            The cell width.
+        height : float
+            The cell height.
+        edgecolor : color
+            The color of the cell border.
+        facecolor : color
+            The cell facecolor.
+        fill : bool
+            Whether the cell background is filled.
+        text : str
+            The cell text.
+        loc : {'left', 'center', 'right'}, default: 'right'
+            The alignment of the text within the cell.
+        fontproperties : dict
+            A dict defining the font properties of the text. Supported keys and
+            values are the keyword arguments accepted by `.FontProperties`.
+        visible_edges : str, default: 'closed'
+            The cell edges to be drawn with a line: a substring of 'BRTL'
+            (bottom, right, top, left), or one of 'open' (no edges drawn),
+            'closed' (all edges drawn), 'horizontal' (bottom and top),
+            'vertical' (right and left).
+        """
 
         # Call base
-        Rectangle.__init__(self, xy, width=width, height=height, fill=fill,
-                           edgecolor=edgecolor, facecolor=facecolor)
+        super().__init__(xy, width=width, height=height, fill=fill,
+                         edgecolor=edgecolor, facecolor=facecolor)
         self.set_clip_on(False)
+        self.visible_edges = visible_edges
 
         # Create text object
         if loc is None:
             loc = 'right'
         self._loc = loc
-        self._text = Text(x=xy[0], y=xy[1], text=text,
-                          fontproperties=fontproperties)
-        self._text.set_clip_on(False)
+        self._text = Text(x=xy[0], y=xy[1], clip_on=False,
+                          text=text, fontproperties=fontproperties,
+                          horizontalalignment=loc, verticalalignment='center')
 
-    def set_transform(self, trans):
-        Rectangle.set_transform(self, trans)
+    @_api.rename_parameter("3.8", "trans", "t")
+    def set_transform(self, t):
+        super().set_transform(t)
         # the text does not get the transform!
         self.stale = True
 
     def set_figure(self, fig):
-        Rectangle.set_figure(self, fig)
+        super().set_figure(fig)
         self._text.set_figure(fig)
 
     def get_text(self):
@@ -121,80 +143,52 @@ class Cell(Rectangle):
         if not self.get_visible():
             return
         # draw the rectangle
-        Rectangle.draw(self, renderer)
-
+        super().draw(renderer)
         # position the text
         self._set_text_position(renderer)
         self._text.draw(renderer)
         self.stale = False
 
     def _set_text_position(self, renderer):
-        """Set text up so it draws in the right place.
-
-        Currently support 'left', 'center' and 'right'
-        """
+        """Set text up so it is drawn in the right place."""
         bbox = self.get_window_extent(renderer)
-        l, b, w, h = bbox.bounds
-
-        # draw in center vertically
-        self._text.set_verticalalignment('center')
-        y = b + (h / 2.0)
-
-        # now position horizontally
-        if self._loc == 'center':
-            self._text.set_horizontalalignment('center')
-            x = l + (w / 2.0)
-        elif self._loc == 'left':
-            self._text.set_horizontalalignment('left')
-            x = l + (w * self.PAD)
-        else:
-            self._text.set_horizontalalignment('right')
-            x = l + (w * (1.0 - self.PAD))
-
+        # center vertically
+        y = bbox.y0 + bbox.height / 2
+        # position horizontally
+        loc = self._text.get_horizontalalignment()
+        if loc == 'center':
+            x = bbox.x0 + bbox.width / 2
+        elif loc == 'left':
+            x = bbox.x0 + bbox.width * self.PAD
+        else:  # right.
+            x = bbox.x0 + bbox.width * (1 - self.PAD)
         self._text.set_position((x, y))
 
     def get_text_bounds(self, renderer):
         """
         Return the text bounds as *(x, y, width, height)* in table coordinates.
         """
-        bbox = self._text.get_window_extent(renderer)
-        bboxa = bbox.inverse_transformed(self.get_data_transform())
-        return bboxa.bounds
+        return (self._text.get_window_extent(renderer)
+                .transformed(self.get_data_transform().inverted())
+                .bounds)
 
     def get_required_width(self, renderer):
         """Return the minimal required width for the cell."""
         l, b, w, h = self.get_text_bounds(renderer)
         return w * (1.0 + (2.0 * self.PAD))
 
-    @docstring.dedent_interpd
+    @_docstring.dedent_interpd
     def set_text_props(self, **kwargs):
         """
         Update the text properties.
 
         Valid keyword arguments are:
 
-        %(Text)s
+        %(Text:kwdoc)s
         """
-        self._text.update(kwargs)
+        self._text._internal_update(kwargs)
         self.stale = True
 
-
-class CustomCell(Cell):
-    """
-    A `.Cell` subclass with configurable edge visibility.
-    """
-
-    _edges = 'BRTL'
-    _edge_aliases = {'open':         '',
-                     'closed':       _edges,  # default
-                     'horizontal':   'BT',
-                     'vertical':     'RL'
-                     }
-
-    def __init__(self, *args, visible_edges, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.visible_edges = visible_edges
-
     @property
     def visible_edges(self):
         """
@@ -239,6 +233,9 @@ class CustomCell(Cell):
             )
 
 
+CustomCell = Cell  # Backcompat. alias.
+
+
 class Table(Artist):
     """
     A table of cells.
@@ -284,12 +281,12 @@ class Table(Artist):
         """
         Parameters
         ----------
-        ax : `matplotlib.axes.Axes`
+        ax : `~matplotlib.axes.Axes`
             The `~.axes.Axes` to plot the table into.
         loc : str
             The position of the cell with respect to *ax*. This must be one of
             the `~.Table.codes`.
-        bbox : `.Bbox` or None
+        bbox : `.Bbox` or [xmin, ymin, width, height], optional
             A bounding box to draw the table into. If this is not *None*, this
             overrides *loc*.
 
@@ -299,16 +296,13 @@ class Table(Artist):
             `.Artist` properties.
         """
 
-        Artist.__init__(self)
+        super().__init__()
 
         if isinstance(loc, str):
             if loc not in self.codes:
-                cbook.warn_deprecated(
-                    "3.1", message="Unrecognized location {!r}. Falling back "
-                    "on 'bottom'; valid locations are\n\t{}\n"
-                    "This will raise an exception %(removal)s."
+                raise ValueError(
+                    "Unrecognized location {!r}. Valid locations are\n\t{}"
                     .format(loc, '\n\t'.join(self.codes)))
-                loc = 'bottom'
             loc = self.codes[loc]
         self.set_figure(ax.figure)
         self._axes = ax
@@ -323,7 +317,7 @@ class Table(Artist):
         self._edges = None
         self._autoColumns = []
         self._autoFontsize = True
-        self.update(kwargs)
+        self._internal_update(kwargs)
 
         self.set_clip_on(False)
 
@@ -342,12 +336,12 @@ class Table(Artist):
 
         Returns
         -------
-        cell : `.CustomCell`
+        `.Cell`
             The created cell.
 
         """
         xy = (0, 0)
-        cell = CustomCell(xy, visible_edges=self.edges, *args, **kwargs)
+        cell = Cell(xy, visible_edges=self.edges, *args, **kwargs)
         self[row, col] = cell
         return cell
 
@@ -355,11 +349,12 @@ class Table(Artist):
         """
         Set a custom cell in a given position.
         """
-        cbook._check_isinstance(CustomCell, cell=cell)
+        _api.check_isinstance(Cell, cell=cell)
         try:
             row, col = position[0], position[1]
-        except Exception:
-            raise KeyError('Only tuples length 2 are accepted as coordinates')
+        except Exception as err:
+            raise KeyError('Only tuples length 2 are accepted as '
+                           'coordinates') from err
         cell.set_figure(self.figure)
         cell.set_transform(self.get_transform())
         cell.set_clip_on(False)
@@ -373,7 +368,7 @@ class Table(Artist):
     @property
     def edges(self):
         """
-        The default value of `~.CustomCell.visible_edges` for newly added
+        The default value of `~.Cell.visible_edges` for newly added
         cells using `.add_cell`.
 
         Notes
@@ -405,7 +400,7 @@ class Table(Artist):
         # Need a renderer to do hit tests on mouseevent; assume the last one
         # will do
         if renderer is None:
-            renderer = self.figure._cachedRenderer
+            renderer = self.figure._get_renderer()
         if renderer is None:
             raise RuntimeError('No renderer defined')
 
@@ -422,7 +417,7 @@ class Table(Artist):
 
     def _get_grid_bbox(self, renderer):
         """
-        Get a bbox, in axes co-ordinates for the cells.
+        Get a bbox, in axes coordinates for the cells.
 
         Only include those in the range (0, 0) to (maxRow, maxCol).
         """
@@ -430,16 +425,15 @@ class Table(Artist):
                  for (row, col), cell in self._cells.items()
                  if row >= 0 and col >= 0]
         bbox = Bbox.union(boxes)
-        return bbox.inverse_transformed(self.get_transform())
+        return bbox.transformed(self.get_transform().inverted())
 
     def contains(self, mouseevent):
         # docstring inherited
-        inside, info = self._default_contains(mouseevent)
-        if inside is not None:
-            return inside, info
+        if self._different_canvas(mouseevent):
+            return False, {}
         # TODO: Return index of the cell containing the cursor so that the user
         # doesn't have to bind to each one individually.
-        renderer = self.figure._cachedRenderer
+        renderer = self.figure._get_renderer()
         if renderer is not None:
             boxes = [cell.get_window_extent(renderer)
                      for (row, col), cell in self._cells.items()
@@ -453,8 +447,10 @@ class Table(Artist):
         """Return the Artists contained by the table."""
         return list(self._cells.values())
 
-    def get_window_extent(self, renderer):
-        """Return the bounding box of the table in window coords."""
+    def get_window_extent(self, renderer=None):
+        # docstring inherited
+        if renderer is None:
+            renderer = self.figure._get_renderer()
         self._update_positions(renderer)
         boxes = [cell.get_window_extent(renderer)
                  for cell in self._cells.values()]
@@ -500,14 +496,15 @@ class Table(Artist):
         col : int or sequence of ints
             The indices of the columns to auto-scale.
         """
-        # check for col possibility on iteration
-        try:
-            iter(col)
-        except (TypeError, AttributeError):
-            self._autoColumns.append(col)
-        else:
-            for cell in col:
-                self._autoColumns.append(cell)
+        col1d = np.atleast_1d(col)
+        if not np.issubdtype(col1d.dtype, np.integer):
+            _api.warn_deprecated("3.8", name="col",
+                                 message="%(name)r must be an int or sequence of ints. "
+                                 "Passing other types is deprecated since %(since)s "
+                                 "and will be removed %(removal)s.")
+            return
+        for cell in col1d:
+            self._autoColumns.append(cell)
 
         self.stale = True
 
@@ -599,7 +596,10 @@ class Table(Artist):
 
         if self._bbox is not None:
             # Position according to bbox
-            rl, rb, rw, rh = self._bbox
+            if isinstance(self._bbox, Bbox):
+                rl, rb, rw, rh = self._bbox.bounds
+            else:
+                rl, rb, rw, rh = self._bbox
             self.scale(rw / w, rh / h)
             ox = rl - l
             oy = rb - b
@@ -651,10 +651,7 @@ class Table(Artist):
         return self._cells
 
 
-docstring.interpd.update(Table=artist.kwdoc(Table))
-
-
-@docstring.dedent_interpd
+@_docstring.dedent_interpd
 def table(ax,
           cellText=None, cellColours=None,
           cellLoc='right', colWidths=None,
@@ -701,7 +698,7 @@ def table(ax,
     rowColours : list of colors, optional
         The colors of the row header cells.
 
-    rowLoc : {'left', 'center', 'right'}, optional, default: 'left'
+    rowLoc : {'left', 'center', 'right'}, default: 'left'
         The text alignment of the row header cells.
 
     colLabels : list of str, optional
@@ -710,32 +707,32 @@ def table(ax,
     colColours : list of colors, optional
         The colors of the column header cells.
 
-    colLoc : {'left', 'center', 'right'}, optional, default: 'left'
+    colLoc : {'left', 'center', 'right'}, default: 'left'
         The text alignment of the column header cells.
 
     loc : str, optional
         The position of the cell with respect to *ax*. This must be one of
         the `~.Table.codes`.
 
-    bbox : `.Bbox`, optional
+    bbox : `.Bbox` or [xmin, ymin, width, height], optional
         A bounding box to draw the table into. If this is not *None*, this
         overrides *loc*.
 
     edges : substring of 'BRTL' or {'open', 'closed', 'horizontal', 'vertical'}
         The cell edges to be drawn with a line. See also
-        `~.CustomCell.visible_edges`.
+        `~.Cell.visible_edges`.
+
+    Returns
+    -------
+    `~matplotlib.table.Table`
+        The created table.
 
     Other Parameters
     ----------------
     **kwargs
         `.Table` properties.
 
-    %(Table)s
-
-    Returns
-    -------
-    table : `~matplotlib.table.Table`
-        The created table.
+    %(Table:kwdoc)s
     """
 
     if cellColours is None and cellText is None:
@@ -753,16 +750,16 @@ def table(ax,
     cols = len(cellText[0])
     for row in cellText:
         if len(row) != cols:
-            raise ValueError("Each row in 'cellText' must have {} columns"
-                             .format(cols))
+            raise ValueError(f"Each row in 'cellText' must have {cols} "
+                             "columns")
 
     if cellColours is not None:
         if len(cellColours) != rows:
-            raise ValueError("'cellColours' must have {} rows".format(rows))
+            raise ValueError(f"'cellColours' must have {rows} rows")
         for row in cellColours:
             if len(row) != cols:
-                raise ValueError("Each row in 'cellColours' must have {} "
-                                 "columns".format(cols))
+                raise ValueError("Each row in 'cellColours' must have "
+                                 f"{cols} columns")
     else:
         cellColours = ['w' * cols] * rows
 
@@ -782,7 +779,7 @@ def table(ax,
 
     if rowLabels is not None:
         if len(rowLabels) != rows:
-            raise ValueError("'rowLabels' must be of length {0}".format(rows))
+            raise ValueError(f"'rowLabels' must be of length {rows}")
 
     # If we have column labels, need to shift
     # the text and colour arrays down 1 row
