@@ -1,25 +1,29 @@
 """
-Provides a collection of utilities for comparing (image) results.
-
+Utilities for comparing image results.
 """
 
 import atexit
+import functools
 import hashlib
+import logging
 import os
 from pathlib import Path
-import re
 import shutil
 import subprocess
 import sys
-from tempfile import TemporaryFile
+from tempfile import TemporaryDirectory, TemporaryFile
+import weakref
 
 import numpy as np
+from PIL import Image
 
 import matplotlib as mpl
-from matplotlib.testing.exceptions import ImageComparisonFailure
 from matplotlib import cbook
+from matplotlib.testing.exceptions import ImageComparisonFailure
 
-__all__ = ['compare_images', 'comparable_formats']
+_log = logging.getLogger(__name__)
+
+__all__ = ['calculate_rms', 'comparable_formats', 'compare_images']
 
 
 def make_test_filename(fname, purpose):
@@ -27,21 +31,17 @@ def make_test_filename(fname, purpose):
     Make a new filename by inserting *purpose* before the file's extension.
     """
     base, ext = os.path.splitext(fname)
-    return '%s-%s%s' % (base, purpose, ext)
+    return f'{base}-{purpose}{ext}'
+
+
+def _get_cache_path():
+    cache_dir = Path(mpl.get_cachedir(), 'test_cache')
+    cache_dir.mkdir(parents=True, exist_ok=True)
+    return cache_dir
 
 
 def get_cache_dir():
-    cachedir = mpl.get_cachedir()
-    if cachedir is None:
-        raise RuntimeError('Could not find a suitable configuration directory')
-    cache_dir = os.path.join(cachedir, 'test_cache')
-    try:
-        Path(cache_dir).mkdir(parents=True, exist_ok=True)
-    except IOError:
-        return None
-    if not os.access(cache_dir, os.W_OK):
-        return None
-    return cache_dir
+    return str(_get_cache_path())
 
 
 def get_file_hash(path, block_size=2 ** 20):
@@ -53,43 +53,16 @@ def get_file_hash(path, block_size=2 ** 20):
                 break
             md5.update(data)
 
-    if path.endswith('.pdf'):
+    if Path(path).suffix == '.pdf':
         md5.update(str(mpl._get_executable_info("gs").version)
                    .encode('utf-8'))
-    elif path.endswith('.svg'):
+    elif Path(path).suffix == '.svg':
         md5.update(str(mpl._get_executable_info("inkscape").version)
                    .encode('utf-8'))
 
     return md5.hexdigest()
 
 
-def make_external_conversion_command(cmd):
-    def convert(old, new):
-        cmdline = cmd(old, new)
-        pipe = subprocess.Popen(cmdline, universal_newlines=True,
-                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout, stderr = pipe.communicate()
-        errcode = pipe.wait()
-        if not os.path.exists(new) or errcode:
-            msg = "Conversion command failed:\n%s\n" % ' '.join(cmdline)
-            if stdout:
-                msg += "Standard output:\n%s\n" % stdout
-            if stderr:
-                msg += "Standard error:\n%s\n" % stderr
-            raise IOError(msg)
-
-    return convert
-
-
-# Modified from https://bugs.python.org/issue25567.
-_find_unsafe_bytes = re.compile(br'[^a-zA-Z0-9_@%+=:,./-]').search
-
-
-def _shlex_quote_bytes(b):
-    return (b if _find_unsafe_bytes(b) is None
-            else b"'" + b.replace(b"'", b"'\"'\"'") + b"'")
-
-
 class _ConverterError(Exception):
     pass
 
@@ -119,10 +92,10 @@ class _Converter:
         while True:
             c = self._proc.stdout.read(1)
             if not c:
-                raise _ConverterError
+                raise _ConverterError(os.fsdecode(bytes(buf)))
             buf.extend(c)
             if buf.endswith(terminator):
-                return bytes(buf[:-len(terminator)])
+                return bytes(buf)
 
 
 class _GSConverter(_Converter):
@@ -130,13 +103,13 @@ class _GSConverter(_Converter):
         if not self._proc:
             self._proc = subprocess.Popen(
                 [mpl._get_executable_info("gs").executable,
-                 "-dNOSAFER", "-dNOPAUSE", "-sDEVICE=png16m"],
+                 "-dNOSAFER", "-dNOPAUSE", "-dEPSCrop", "-sDEVICE=png16m"],
                 # As far as I can see, ghostscript never outputs to stderr.
                 stdin=subprocess.PIPE, stdout=subprocess.PIPE)
             try:
                 self._read_until(b"\nGS")
-            except _ConverterError:
-                raise OSError("Failed to start Ghostscript")
+            except _ConverterError as e:
+                raise OSError(f"Failed to start Ghostscript:\n\n{e.args[0]}") from None
 
         def encode_and_escape(name):
             return (os.fsencode(name)
@@ -152,69 +125,107 @@ class _GSConverter(_Converter):
             + b") run flush\n")
         self._proc.stdin.flush()
         # GS> if nothing left on the stack; GS<n> if n items left on the stack.
-        err = self._read_until(b"GS")
-        stack = self._read_until(b">")
+        err = self._read_until((b"GS<", b"GS>"))
+        stack = self._read_until(b">") if err.endswith(b"GS<") else b""
         if stack or not os.path.exists(dest):
-            stack_size = int(stack[1:]) if stack else 0
+            stack_size = int(stack[:-1]) if stack else 0
             self._proc.stdin.write(b"pop\n" * stack_size)
             # Using the systemencoding should at least get the filenames right.
             raise ImageComparisonFailure(
-                (err + b"GS" + stack + b">")
-                .decode(sys.getfilesystemencoding(), "replace"))
+                (err + stack).decode(sys.getfilesystemencoding(), "replace"))
 
 
 class _SVGConverter(_Converter):
     def __call__(self, orig, dest):
+        old_inkscape = mpl._get_executable_info("inkscape").version.major < 1
+        terminator = b"\n>" if old_inkscape else b"> "
+        if not hasattr(self, "_tmpdir"):
+            self._tmpdir = TemporaryDirectory()
+            # On Windows, we must make sure that self._proc has terminated
+            # (which __del__ does) before clearing _tmpdir.
+            weakref.finalize(self._tmpdir, self.__del__)
         if (not self._proc  # First run.
                 or self._proc.poll() is not None):  # Inkscape terminated.
-            env = os.environ.copy()
-            # If one passes e.g. a png file to Inkscape, it will try to
-            # query the user for conversion options via a GUI (even with
-            # `--without-gui`).  Unsetting `DISPLAY` prevents this (and causes
-            # GTK to crash and Inkscape to terminate, but that'll just be
-            # reported as a regular exception below).
-            env.pop("DISPLAY", None)  # May already be unset.
-            # Do not load any user options.
-            env["INKSCAPE_PROFILE_DIR"] = os.devnull
-            # Old versions of Inkscape (0.48.3.1, used on Travis as of now)
-            # seem to sometimes deadlock when stderr is redirected to a pipe,
-            # so we redirect it to a temporary file instead.  This is not
-            # necessary anymore as of Inkscape 0.92.1.
+            if self._proc is not None and self._proc.poll() is not None:
+                for stream in filter(None, [self._proc.stdin,
+                                            self._proc.stdout,
+                                            self._proc.stderr]):
+                    stream.close()
+            env = {
+                **os.environ,
+                # If one passes e.g. a png file to Inkscape, it will try to
+                # query the user for conversion options via a GUI (even with
+                # `--without-gui`).  Unsetting `DISPLAY` prevents this (and
+                # causes GTK to crash and Inkscape to terminate, but that'll
+                # just be reported as a regular exception below).
+                "DISPLAY": "",
+                # Do not load any user options.
+                "INKSCAPE_PROFILE_DIR": self._tmpdir.name,
+            }
+            # Old versions of Inkscape (e.g. 0.48.3.1) seem to sometimes
+            # deadlock when stderr is redirected to a pipe, so we redirect it
+            # to a temporary file instead.  This is not necessary anymore as of
+            # Inkscape 0.92.1.
             stderr = TemporaryFile()
             self._proc = subprocess.Popen(
-                ["inkscape", "--without-gui", "--shell"],
-                stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                stderr=stderr, env=env)
+                ["inkscape", "--without-gui", "--shell"] if old_inkscape else
+                ["inkscape", "--shell"],
+                stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=stderr,
+                env=env, cwd=self._tmpdir.name)
             # Slight abuse, but makes shutdown handling easier.
             self._proc.stderr = stderr
             try:
-                self._read_until(b"\n>")
-            except _ConverterError:
-                raise OSError("Failed to start Inkscape in interactive mode")
+                self._read_until(terminator)
+            except _ConverterError as err:
+                raise OSError(
+                    "Failed to start Inkscape in interactive mode:\n\n"
+                    + err.args[0]) from err
 
-        # Inkscape uses glib's `g_shell_parse_argv`, which has a consistent
-        # behavior across platforms, so we can just use `shlex.quote`.
-        orig_b, dest_b = map(_shlex_quote_bytes,
-                             map(os.fsencode, [orig, dest]))
-        if b"\n" in orig_b or b"\n" in dest_b:
-            # Who knows whether the current folder name has a newline, or if
-            # our encoding is even ASCII compatible...  Just fall back on the
-            # slow solution (Inkscape uses `fgets` so it will always stop at a
-            # newline).
-            return make_external_conversion_command(lambda old, new: [
-                'inkscape', '-z', old, '--export-png', new])(orig, dest)
-        self._proc.stdin.write(orig_b + b" --export-png=" + dest_b + b"\n")
+        # Inkscape's shell mode does not support escaping metacharacters in the
+        # filename ("\n", and ":;" for inkscape>=1).  Avoid any problems by
+        # running from a temporary directory and using fixed filenames.
+        inkscape_orig = Path(self._tmpdir.name, os.fsdecode(b"f.svg"))
+        inkscape_dest = Path(self._tmpdir.name, os.fsdecode(b"f.png"))
+        try:
+            inkscape_orig.symlink_to(Path(orig).resolve())
+        except OSError:
+            shutil.copyfile(orig, inkscape_orig)
+        self._proc.stdin.write(
+            b"f.svg --export-png=f.png\n" if old_inkscape else
+            b"file-open:f.svg;export-filename:f.png;export-do;file-close\n")
         self._proc.stdin.flush()
         try:
-            self._read_until(b"\n>")
-        except _ConverterError:
+            self._read_until(terminator)
+        except _ConverterError as err:
             # Inkscape's output is not localized but gtk's is, so the output
             # stream probably has a mixed encoding.  Using the filesystem
             # encoding should at least get the filenames right...
             self._proc.stderr.seek(0)
             raise ImageComparisonFailure(
                 self._proc.stderr.read().decode(
-                    sys.getfilesystemencoding(), "replace"))
+                    sys.getfilesystemencoding(), "replace")) from err
+        os.remove(inkscape_orig)
+        shutil.move(inkscape_dest, dest)
+
+    def __del__(self):
+        super().__del__()
+        if hasattr(self, "_tmpdir"):
+            self._tmpdir.cleanup()
+
+
+class _SVGWithMatplotlibFontsConverter(_SVGConverter):
+    """
+    A SVG converter which explicitly adds the fonts shipped by Matplotlib to
+    Inkspace's font search path, to better support `svg.fonttype = "none"`
+    (which is in particular used by certain mathtext tests).
+    """
+
+    def __call__(self, orig, dest):
+        if not hasattr(self, "_tmpdir"):
+            self._tmpdir = TemporaryDirectory()
+            shutil.copytree(cbook._get_data_path("fonts/ttf"),
+                            Path(self._tmpdir.name, "fonts"))
+        return super().__call__(orig, dest)
 
 
 def _update_converter():
@@ -232,12 +243,11 @@ def _update_converter():
         converter['svg'] = _SVGConverter()
 
 
-#: A dictionary that maps filename extensions to functions which
-#: themselves map arguments `old` and `new` (filenames) to a list of strings.
-#: The list can then be passed to Popen to convert files with that
-#: extension to png format.
+#: A dictionary that maps filename extensions to functions which themselves
+#: convert between arguments `old` and `new` (filenames).
 converter = {}
 _update_converter()
+_svg_with_matplotlib_fonts_converter = _SVGWithMatplotlibFontsConverter()
 
 
 def comparable_formats():
@@ -247,7 +257,7 @@ def comparable_formats():
 
     Returns
     -------
-    supported_formats : list of str
+    list of str
         E.g. ``['png', 'pdf', 'svg', 'eps']``.
 
     """
@@ -260,40 +270,75 @@ def convert(filename, cache):
 
     If *cache* is True, the result of the conversion is cached in
     `matplotlib.get_cachedir() + '/test_cache/'`.  The caching is based on a
-    hash of the exact contents of the input file.  There is no limit on the
-    size of the cache, so it may need to be manually cleared periodically.
+    hash of the exact contents of the input file.  Old cache entries are
+    automatically deleted as needed to keep the size of the cache capped to
+    twice the size of all baseline images.
     """
-    base, extension = os.fspath(filename).rsplit('.', 1)
-    if extension not in converter:
+    path = Path(filename)
+    if not path.exists():
+        raise OSError(f"{path} does not exist")
+    if path.suffix[1:] not in converter:
         import pytest
-        pytest.skip(f"Don't know how to convert {extension} files to png")
-    newname = base + '_' + extension + '.png'
-    if not os.path.exists(filename):
-        raise IOError("'%s' does not exist" % filename)
+        pytest.skip(f"Don't know how to convert {path.suffix} files to png")
+    newpath = path.parent / f"{path.stem}_{path.suffix[1:]}.png"
 
     # Only convert the file if the destination doesn't already exist or
     # is out of date.
-    if (not os.path.exists(newname) or
-            os.stat(newname).st_mtime < os.stat(filename).st_mtime):
-        if cache:
-            cache_dir = get_cache_dir()
-        else:
-            cache_dir = None
+    if not newpath.exists() or newpath.stat().st_mtime < path.stat().st_mtime:
+        cache_dir = _get_cache_path() if cache else None
 
         if cache_dir is not None:
-            hash_value = get_file_hash(filename)
-            new_ext = os.path.splitext(newname)[1]
-            cached_file = os.path.join(cache_dir, hash_value + new_ext)
-            if os.path.exists(cached_file):
-                shutil.copyfile(cached_file, newname)
-                return newname
+            _register_conversion_cache_cleaner_once()
+            hash_value = get_file_hash(path)
+            cached_path = cache_dir / (hash_value + newpath.suffix)
+            if cached_path.exists():
+                _log.debug("For %s: reusing cached conversion.", filename)
+                shutil.copyfile(cached_path, newpath)
+                return str(newpath)
 
-        converter[extension](filename, newname)
+        _log.debug("For %s: converting to png.", filename)
+        convert = converter[path.suffix[1:]]
+        if path.suffix == ".svg":
+            contents = path.read_text()
+            if 'style="font:' in contents:
+                # for svg.fonttype = none, we explicitly patch the font search
+                # path so that fonts shipped by Matplotlib are found.
+                convert = _svg_with_matplotlib_fonts_converter
+        convert(path, newpath)
 
         if cache_dir is not None:
-            shutil.copyfile(newname, cached_file)
+            _log.debug("For %s: caching conversion result.", filename)
+            shutil.copyfile(newpath, cached_path)
 
-    return newname
+    return str(newpath)
+
+
+def _clean_conversion_cache():
+    # This will actually ignore mpl_toolkits baseline images, but they're
+    # relatively small.
+    baseline_images_size = sum(
+        path.stat().st_size
+        for path in Path(mpl.__file__).parent.glob("**/baseline_images/**/*"))
+    # 2x: one full copy of baselines, and one full copy of test results
+    # (actually an overestimate: we don't convert png baselines and results).
+    max_cache_size = 2 * baseline_images_size
+    # Reduce cache until it fits.
+    with cbook._lock_path(_get_cache_path()):
+        cache_stat = {
+            path: path.stat() for path in _get_cache_path().glob("*")}
+        cache_size = sum(stat.st_size for stat in cache_stat.values())
+        paths_by_atime = sorted(  # Oldest at the end.
+            cache_stat, key=lambda path: cache_stat[path].st_atime,
+            reverse=True)
+        while cache_size > max_cache_size:
+            path = paths_by_atime.pop()
+            cache_size -= cache_stat[path].st_size
+            path.unlink()
+
+
+@functools.cache  # Ensure this is only registered once.
+def _register_conversion_cache_cleaner_once():
+    atexit.register(_clean_conversion_cache)
 
 
 def crop_to_same(actual_path, actual_image, expected_path, expected_image):
@@ -308,15 +353,31 @@ def crop_to_same(actual_path, actual_image, expected_path, expected_image):
 
 
 def calculate_rms(expected_image, actual_image):
-    "Calculate the per-pixel errors, then compute the root mean square error."
+    """
+    Calculate the per-pixel errors, then compute the root mean square error.
+    """
     if expected_image.shape != actual_image.shape:
         raise ImageComparisonFailure(
-            "Image sizes do not match expected size: {} "
-            "actual size {}".format(expected_image.shape, actual_image.shape))
+            f"Image sizes do not match expected size: {expected_image.shape} "
+            f"actual size {actual_image.shape}")
     # Convert to float to avoid overflowing finite integer types.
     return np.sqrt(((expected_image - actual_image).astype(float) ** 2).mean())
 
 
+# NOTE: compare_image and save_diff_image assume that the image does not have
+# 16-bit depth, as Pillow converts these to RGB incorrectly.
+
+
+def _load_image(path):
+    img = Image.open(path)
+    # In an RGBA image, if the smallest value in the alpha channel is 255, all
+    # values in it must be 255, meaning that the image is opaque. If so,
+    # discard the alpha channel so that it may compare equal to an RGB image.
+    if img.mode != "RGBA" or img.getextrema()[3][0] == 255:
+        img = img.convert("RGB")
+    return np.asarray(img)
+
+
 def compare_images(expected, actual, tol, in_decorator=False):
     """
     Compare two "image" files checking differences within a tolerance.
@@ -341,7 +402,7 @@ def compare_images(expected, actual, tol, in_decorator=False):
 
     Returns
     -------
-    comparison_result : None or dict or str
+    None or dict or str
         Return *None* if the images are equal within the given tolerance.
 
         If the images differ, the return value depends on  *in_decorator*.
@@ -366,28 +427,24 @@ def compare_images(expected, actual, tol, in_decorator=False):
         compare_images(img1, img2, 0.001)
 
     """
-    from matplotlib import _png
-
     actual = os.fspath(actual)
     if not os.path.exists(actual):
-        raise Exception("Output image %s does not exist." % actual)
+        raise Exception(f"Output image {actual} does not exist.")
     if os.stat(actual).st_size == 0:
-        raise Exception("Output image file %s is empty." % actual)
+        raise Exception(f"Output image file {actual} is empty.")
 
     # Convert the image to png
     expected = os.fspath(expected)
     if not os.path.exists(expected):
-        raise IOError('Baseline image %r does not exist.' % expected)
+        raise OSError(f'Baseline image {expected!r} does not exist.')
     extension = expected.split('.')[-1]
     if extension != 'png':
-        actual = convert(actual, False)
-        expected = convert(expected, True)
+        actual = convert(actual, cache=True)
+        expected = convert(expected, cache=True)
 
-    # open the image files and remove the alpha channel (if it exists)
-    with open(expected, "rb") as expected_file:
-        expected_image = _png.read_png_int(expected_file)[:, :, :3]
-    with open(actual, "rb") as actual_file:
-        actual_image = _png.read_png_int(actual_file)[:, :, :3]
+    # open the image files
+    expected_image = _load_image(expected)
+    actual_image = _load_image(actual)
 
     actual_image, expected_image = crop_to_same(
         actual, actual_image, expected, expected_image)
@@ -426,7 +483,7 @@ def compare_images(expected, actual, tol, in_decorator=False):
 
 
 def save_diff_image(expected, actual, output):
-    '''
+    """
     Parameters
     ----------
     expected : str
@@ -435,37 +492,24 @@ def save_diff_image(expected, actual, output):
         File path of actual image.
     output : str
         File path to save difference image to.
-    '''
-    # Drop alpha channels, similarly to compare_images.
-    from matplotlib import _png
-    with open(expected, "rb") as expected_file:
-        expected_image = _png.read_png(expected_file)[..., :3]
-    with open(actual, "rb") as actual_file:
-        actual_image = _png.read_png(actual_file)[..., :3]
+    """
+    expected_image = _load_image(expected)
+    actual_image = _load_image(actual)
     actual_image, expected_image = crop_to_same(
         actual, actual_image, expected, expected_image)
-    expected_image = np.array(expected_image).astype(float)
-    actual_image = np.array(actual_image).astype(float)
+    expected_image = np.array(expected_image, float)
+    actual_image = np.array(actual_image, float)
     if expected_image.shape != actual_image.shape:
         raise ImageComparisonFailure(
-            "Image sizes do not match expected size: {} "
-            "actual size {}".format(expected_image.shape, actual_image.shape))
-    abs_diff_image = np.abs(expected_image - actual_image)
+            f"Image sizes do not match expected size: {expected_image.shape} "
+            f"actual size {actual_image.shape}")
+    abs_diff = np.abs(expected_image - actual_image)
 
     # expand differences in luminance domain
-    abs_diff_image *= 255 * 10
-    save_image_np = np.clip(abs_diff_image, 0, 255).astype(np.uint8)
-    height, width, depth = save_image_np.shape
+    abs_diff *= 10
+    abs_diff = np.clip(abs_diff, 0, 255).astype(np.uint8)
 
-    # The PDF renderer doesn't produce an alpha channel, but the
-    # matplotlib PNG writer requires one, so expand the array
-    if depth == 3:
-        with_alpha = np.empty((height, width, 4), dtype=np.uint8)
-        with_alpha[:, :, 0:3] = save_image_np
-        save_image_np = with_alpha
+    if abs_diff.shape[2] == 4:  # Hard-code the alpha channel to fully solid
+        abs_diff[:, :, 3] = 255
 
-    # Hard-code the alpha channel to fully solid
-    save_image_np[:, :, 3] = 255
-
-    with open(output, "wb") as output_file:
-        _png.write_png(save_image_np, output_file)
+    Image.fromarray(abs_diff).save(output, format="png")
