@@ -396,7 +396,7 @@ def test_constrained_layout23():
         fig = plt.figure(layout="constrained", clear=True, num="123")
         gs = fig.add_gridspec(1, 2)
         sub = gs[0].subgridspec(2, 2)
-        fig.suptitle("Suptitle{}".format(i))
+        fig.suptitle(f"Suptitle{i}")
 
 
 @image_comparison(['test_colorbar_location.png'],
