@@ -1,5 +1,6 @@
 from contextlib import ExitStack
 from copy import copy
+import functools
 import io
 import os
 from pathlib import Path
@@ -26,6 +27,7 @@ import pytest
 @image_comparison(['image_interps'], style='mpl20')
 def test_image_interps():
     """Make the basic nearest, bilinear and bicubic interps."""
+    # Remove texts when this image is regenerated.
     # Remove this line when this test image is regenerated.
     plt.rcParams['text.kerning_factor'] = 6
 
@@ -1181,7 +1183,7 @@ class QuantityND(np.ndarray):
 
     def __getitem__(self, item):
         units = getattr(self, "units", None)
-        ret = super(QuantityND, self).__getitem__(item)
+        ret = super().__getitem__(item)
         if isinstance(ret, QuantityND) or units is not None:
             ret = QuantityND(ret, units)
         return ret
@@ -1464,3 +1466,40 @@ def test_str_norms(fig_test, fig_ref):
     assert type(axts[0].images[0].norm) is colors.LogNorm  # Exactly that class
     with pytest.raises(ValueError):
         axts[0].imshow(t, norm="foobar")
+
+
+def test__resample_valid_output():
+    resample = functools.partial(mpl._image.resample, transform=Affine2D())
+    with pytest.raises(ValueError, match="must be a NumPy array"):
+        resample(np.zeros((9, 9)), None)
+    with pytest.raises(ValueError, match="different dimensionalities"):
+        resample(np.zeros((9, 9)), np.zeros((9, 9, 4)))
+    with pytest.raises(ValueError, match="must be RGBA"):
+        resample(np.zeros((9, 9, 4)), np.zeros((9, 9, 3)))
+    with pytest.raises(ValueError, match="Mismatched types"):
+        resample(np.zeros((9, 9), np.uint8), np.zeros((9, 9)))
+    with pytest.raises(ValueError, match="must be C-contiguous"):
+        resample(np.zeros((9, 9)), np.zeros((9, 9)).T)
+
+
+def test_axesimage_get_shape():
+    # generate dummy image to test get_shape method
+    ax = plt.gca()
+    im = AxesImage(ax)
+    with pytest.raises(RuntimeError, match="You must first set the image array"):
+        im.get_shape()
+    z = np.arange(12, dtype=float).reshape((4, 3))
+    im.set_data(z)
+    assert im.get_shape() == (4, 3)
+    assert im.get_size() == im.get_shape()
+
+
+def test_non_transdata_image_does_not_touch_aspect():
+    ax = plt.figure().add_subplot()
+    im = np.arange(4).reshape((2, 2))
+    ax.imshow(im, transform=ax.transAxes)
+    assert ax.get_aspect() == "auto"
+    ax.imshow(im, transform=Affine2D().scale(2) + ax.transData)
+    assert ax.get_aspect() == 1
+    ax.imshow(im, transform=ax.transAxes, aspect=2)
+    assert ax.get_aspect() == 2
