@@ -1,10 +1,9 @@
-from collections import OrderedDict
 from contextlib import contextmanager
-import gc
 from pathlib import Path
 from tempfile import TemporaryDirectory
 import sys
 
+import numpy as np
 import pytest
 
 import matplotlib as mpl
@@ -22,12 +21,13 @@ def temp_style(style_name, settings=None):
     """Context manager to create a style sheet in a temporary directory."""
     if not settings:
         settings = DUMMY_SETTINGS
-    temp_file = '%s.%s' % (style_name, STYLE_EXTENSION)
+    temp_file = f'{style_name}.{STYLE_EXTENSION}'
     try:
         with TemporaryDirectory() as tmpdir:
             # Write style settings to file in the tmpdir.
             Path(tmpdir, temp_file).write_text(
-                "\n".join("{}: {}".format(k, v) for k, v in settings.items()))
+                "\n".join(f"{k}: {v}" for k, v in settings.items()),
+                encoding="utf-8")
             # Add tmpdir to style path and reload so we can access this style.
             USER_LIBRARY_PATHS.append(tmpdir)
             style.reload_library()
@@ -36,13 +36,14 @@ def temp_style(style_name, settings=None):
         style.reload_library()
 
 
-def test_invalid_rc_warning_includes_filename(capsys):
+def test_invalid_rc_warning_includes_filename(caplog):
     SETTINGS = {'foo': 'bar'}
     basename = 'basename'
     with temp_style(basename, SETTINGS):
         # style.reload_library() in temp_style() triggers the warning
         pass
-    assert basename in capsys.readouterr().err
+    assert (len(caplog.records) == 1
+            and basename in caplog.records[0].getMessage())
 
 
 def test_available():
@@ -59,7 +60,7 @@ def test_use():
 
 def test_use_url(tmpdir):
     path = Path(tmpdir, 'file')
-    path.write_text('axes.facecolor: adeade')
+    path.write_text('axes.facecolor: adeade', encoding='utf-8')
     with temp_style('test', DUMMY_SETTINGS):
         url = ('file:'
                + ('///' if sys.platform == 'win32' else '')
@@ -72,7 +73,7 @@ def test_single_path(tmpdir):
     mpl.rcParams[PARAM] = 'gray'
     temp_file = f'text.{STYLE_EXTENSION}'
     path = Path(tmpdir, temp_file)
-    path.write_text(f'{PARAM} : {VALUE}')
+    path.write_text(f'{PARAM} : {VALUE}', encoding='utf-8')
     with style.context(path):
         assert mpl.rcParams[PARAM] == VALUE
     assert mpl.rcParams[PARAM] == 'gray'
@@ -137,10 +138,9 @@ def test_context_with_union_of_dict_and_namedstyle():
 def test_context_with_badparam():
     original_value = 'gray'
     other_value = 'blue'
-    d = OrderedDict([(PARAM, original_value), ('badparam', None)])
     with style.context({PARAM: other_value}):
         assert mpl.rcParams[PARAM] == other_value
-        x = style.context([d])
+        x = style.context({PARAM: original_value, 'badparam': None})
         with pytest.raises(KeyError):
             with x:
                 pass
@@ -166,7 +166,7 @@ def test_xkcd_no_cm():
     assert mpl.rcParams["path.sketch"] is None
     plt.xkcd()
     assert mpl.rcParams["path.sketch"] == (1, 100, 2)
-    gc.collect()
+    np.testing.break_cycles()
     assert mpl.rcParams["path.sketch"] == (1, 100, 2)
 
 
@@ -175,3 +175,24 @@ def test_xkcd_cm():
     with plt.xkcd():
         assert mpl.rcParams["path.sketch"] == (1, 100, 2)
     assert mpl.rcParams["path.sketch"] is None
+
+
+def test_up_to_date_blacklist():
+    assert mpl.style.core.STYLE_BLACKLIST <= {*mpl.rcsetup._validators}
+
+
+def test_style_from_module(tmp_path, monkeypatch):
+    monkeypatch.syspath_prepend(tmp_path)
+    monkeypatch.chdir(tmp_path)
+    pkg_path = tmp_path / "mpl_test_style_pkg"
+    pkg_path.mkdir()
+    (pkg_path / "test_style.mplstyle").write_text(
+        "lines.linewidth: 42", encoding="utf-8")
+    pkg_path.with_suffix(".mplstyle").write_text(
+        "lines.linewidth: 84", encoding="utf-8")
+    mpl.style.use("mpl_test_style_pkg.test_style")
+    assert mpl.rcParams["lines.linewidth"] == 42
+    mpl.style.use("mpl_test_style_pkg.mplstyle")
+    assert mpl.rcParams["lines.linewidth"] == 84
+    mpl.style.use("./mpl_test_style_pkg.mplstyle")
+    assert mpl.rcParams["lines.linewidth"] == 84
