@@ -1,39 +1,23 @@
 """
-===========================
-Demo Colorbar of Inset Axes
-===========================
+===============================
+Adding a colorbar to inset axes
+===============================
+"""
 
-"""
 import matplotlib.pyplot as plt
 
+from matplotlib import cbook
 from mpl_toolkits.axes_grid1.inset_locator import inset_axes, zoomed_inset_axes
 
-
-def get_demo_image():
-    from matplotlib.cbook import get_sample_data
-    import numpy as np
-    f = get_sample_data("axes_grid/bivariate_normal.npy", asfileobj=False)
-    z = np.load(f)
-    # z is a numpy array of 15x15
-    return z, (-3, 4, -4, 3)
-
-
 fig, ax = plt.subplots(figsize=[5, 4])
+ax.set(aspect=1, xlim=(-15, 15), ylim=(-20, 5))
 
-Z, extent = get_demo_image()
-
-ax.set(aspect=1,
-       xlim=(-15, 15),
-       ylim=(-20, 5))
-
+Z = cbook.get_sample_data("axes_grid/bivariate_normal.npy")
+extent = (-3, 4, -4, 3)
 
 axins = zoomed_inset_axes(ax, zoom=2, loc='upper left')
-im = axins.imshow(Z, extent=extent, interpolation="nearest",
-                  origin="lower")
-
-plt.xticks(visible=False)
-plt.yticks(visible=False)
-
+axins.set(xticks=[], yticks=[])
+im = axins.imshow(Z, extent=extent, origin="lower")
 
 # colorbar
 cax = inset_axes(axins,
@@ -44,7 +28,6 @@ cax = inset_axes(axins,
                  bbox_transform=axins.transAxes,
                  borderpad=0,
                  )
-
 fig.colorbar(im, cax=cax)
 
 plt.show()
