@@ -2,13 +2,13 @@
 ===============
 Parasite Simple
 ===============
-
 """
-from mpl_toolkits.axes_grid1 import host_subplot
+
 import matplotlib.pyplot as plt
 
-host = host_subplot(111)
+from mpl_toolkits.axes_grid1 import host_subplot
 
+host = host_subplot(111)
 par = host.twinx()
 
 host.set_xlabel("Distance")
@@ -18,12 +18,9 @@ par.set_ylabel("Temperature")
 p1, = host.plot([0, 1, 2], [0, 1, 2], label="Density")
 p2, = par.plot([0, 1, 2], [0, 3, 2], label="Temperature")
 
-leg = plt.legend()
+host.legend(labelcolor="linecolor")
 
 host.yaxis.get_label().set_color(p1.get_color())
-leg.texts[0].set_color(p1.get_color())
-
 par.yaxis.get_label().set_color(p2.get_color())
-leg.texts[1].set_color(p2.get_color())
 
 plt.show()
