@@ -4,7 +4,7 @@ Simple Anchored Artists
 =======================
 
 This example illustrates the use of the anchored helper classes found in
-:py:mod:`~matplotlib.offsetbox` and in the :ref:`toolkit_axesgrid1-index`.
+:mod:`matplotlib.offsetbox` and in :mod:`mpl_toolkits.axes_grid1`.
 An implementation of a similar figure, but without use of the toolkit,
 can be found in :doc:`/gallery/misc/anchored_artists`.
 """
@@ -37,8 +37,8 @@ def draw_circle(ax):
     """
     Draw a circle in axis coordinates
     """
-    from mpl_toolkits.axes_grid1.anchored_artists import AnchoredDrawingArea
     from matplotlib.patches import Circle
+    from mpl_toolkits.axes_grid1.anchored_artists import AnchoredDrawingArea
     ada = AnchoredDrawingArea(20, 20, 0, 0,
                               loc='upper right', pad=0., frameon=False)
     p = Circle((10, 10), 10)
@@ -46,18 +46,6 @@ def draw_circle(ax):
     ax.add_artist(ada)
 
 
-def draw_ellipse(ax):
-    """
-    Draw an ellipse of width=0.1, height=0.15 in data coordinates
-    """
-    from mpl_toolkits.axes_grid1.anchored_artists import AnchoredEllipse
-    ae = AnchoredEllipse(ax.transData, width=0.1, height=0.15, angle=0.,
-                         loc='lower left', pad=0.5, borderpad=0.4,
-                         frameon=True)
-
-    ax.add_artist(ae)
-
-
 def draw_sizebar(ax):
     """
     Draw a horizontal bar with length of 0.1 in data coordinates,
@@ -73,12 +61,11 @@ def draw_sizebar(ax):
     ax.add_artist(asb)
 
 
-ax = plt.gca()
+fig, ax = plt.subplots()
 ax.set_aspect(1.)
 
 draw_text(ax)
 draw_circle(ax)
-draw_ellipse(ax)
 draw_sizebar(ax)
 
 plt.show()
