@@ -5,23 +5,20 @@ Simple Axis Pad
 
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
-import mpl_toolkits.axisartist.angle_helper as angle_helper
-import mpl_toolkits.axisartist.grid_finder as grid_finder
+import numpy as np
+
 from matplotlib.projections import PolarAxes
 from matplotlib.transforms import Affine2D
-
 import mpl_toolkits.axisartist as axisartist
-
+import mpl_toolkits.axisartist.angle_helper as angle_helper
+import mpl_toolkits.axisartist.grid_finder as grid_finder
 from mpl_toolkits.axisartist.grid_helper_curvelinear import \
     GridHelperCurveLinear
 
 
 def setup_axes(fig, rect):
-    """
-    polar projection, but in a rectangular box.
-    """
+    """Polar projection, but in a rectangular box."""
 
     # see demo_curvelinear_grid.py for details
     tr = Affine2D().scale(np.pi/180., 1.) + PolarAxes.PolarTransform()
@@ -45,11 +42,9 @@ def setup_axes(fig, rect):
                                         tick_formatter1=tick_formatter1
                                         )
 
-    ax1 = axisartist.Subplot(fig, rect, grid_helper=grid_helper)
+    ax1 = fig.add_subplot(
+        rect, axes_class=axisartist.Axes, grid_helper=grid_helper)
     ax1.axis[:].set_visible(False)
-
-    fig.add_subplot(ax1)
-
     ax1.set_aspect(1.)
     ax1.set_xlim(-5, 12)
     ax1.set_ylim(-5, 10)
