@@ -8,14 +8,14 @@ Reference for colormaps included with Matplotlib.
 A reversed version of each of these colormaps is available by appending
 ``_r`` to the name, as shown in :ref:`reverse-cmap`.
 
-See :doc:`/tutorials/colors/colormaps` for an in-depth discussion about
+See :ref:`colormaps` for an in-depth discussion about
 colormaps, including colorblind-friendliness, and
-:doc:`/tutorials/colors/colormap-manipulation` for a guide to creating
+:ref:`colormap-manipulation` for a guide to creating
 colormaps.
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 cmaps = [('Perceptually Uniform Sequential', [
             'viridis', 'plasma', 'inferno', 'magma', 'cividis']),
@@ -68,7 +68,7 @@ for cmap_category, cmap_list in cmaps:
     plot_color_gradients(cmap_category, cmap_list)
 
 
-###############################################################################
+# %%
 # .. _reverse-cmap:
 #
 # Reversed colormaps
@@ -83,7 +83,7 @@ plot_color_gradients("Original and reversed ", ['viridis', 'viridis_r'])
 # The built-in reversed colormaps are generated using `.Colormap.reversed`.
 # For an example, see :ref:`reversing-colormap`
 
-#############################################################################
+# %%
 #
 # .. admonition:: References
 #
