@@ -7,6 +7,7 @@ Make a "broken" horizontal bar plot, i.e., one with gaps
 """
 import matplotlib.pyplot as plt
 
+# Horizontal bar plot with gaps
 fig, ax = plt.subplots()
 ax.broken_barh([(110, 30), (150, 10)], (10, 9), facecolors='tab:blue')
 ax.broken_barh([(10, 50), (100, 20), (130, 10)], (20, 9),
@@ -14,9 +15,8 @@ ax.broken_barh([(10, 50), (100, 20), (130, 10)], (20, 9),
 ax.set_ylim(5, 35)
 ax.set_xlim(0, 200)
 ax.set_xlabel('seconds since start')
-ax.set_yticks([15, 25])
-ax.set_yticklabels(['Bill', 'Jim'])
-ax.grid(True)
+ax.set_yticks([15, 25], labels=['Bill', 'Jim'])     # Modify y-axis tick labels
+ax.grid(True)                                       # Make grid lines visible
 ax.annotate('race interrupted', (61, 25),
             xytext=(0.8, 0.9), textcoords='axes fraction',
             arrowprops=dict(facecolor='black', shrink=0.05),
