@@ -3,10 +3,10 @@
 Plotting the coherence of two signals
 =====================================
 
-An example showing how to plot the coherence of two signals.
+An example showing how to plot the coherence of two signals using `~.Axes.cohere`.
 """
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 # Fixing random state for reproducibility
 np.random.seed(19680801)
@@ -16,19 +16,18 @@ t = np.arange(0, 30, dt)
 nse1 = np.random.randn(len(t))                 # white noise 1
 nse2 = np.random.randn(len(t))                 # white noise 2
 
-# Two signals with a coherent part at 10Hz and a random part
+# Two signals with a coherent part at 10 Hz and a random part
 s1 = np.sin(2 * np.pi * 10 * t) + nse1
 s2 = np.sin(2 * np.pi * 10 * t) + nse2
 
-fig, axs = plt.subplots(2, 1)
+fig, axs = plt.subplots(2, 1, layout='constrained')
 axs[0].plot(t, s1, t, s2)
 axs[0].set_xlim(0, 2)
-axs[0].set_xlabel('time')
+axs[0].set_xlabel('Time (s)')
 axs[0].set_ylabel('s1 and s2')
 axs[0].grid(True)
 
 cxy, f = axs[1].cohere(s1, s2, 256, 1. / dt)
-axs[1].set_ylabel('coherence')
+axs[1].set_ylabel('Coherence')
 
-fig.tight_layout()
 plt.show()
