@@ -9,6 +9,8 @@ This example showcases the functions hlines and vlines.
 import matplotlib.pyplot as plt
 import numpy as np
 
+# Fixing random state for reproducibility
+np.random.seed(19680801)
 
 t = np.arange(0.0, 5.0, 0.1)
 s = np.exp(-t) + np.sin(2 * np.pi * t) + 1
