@@ -1,16 +1,15 @@
-'''
+"""
 ==============
 3D quiver plot
 ==============
 
-Demonstrates plotting directional arrows at points on a 3d meshgrid.
-'''
+Demonstrates plotting directional arrows at points on a 3D meshgrid.
+"""
 
 import matplotlib.pyplot as plt
 import numpy as np
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 
 # Make the grid
 x, y, z = np.meshgrid(np.arange(-0.8, 1, 0.2),
