@@ -5,14 +5,15 @@ Triangular 3D filled contour plot
 
 Filled contour plots of unstructured triangular grids.
 
-The data used is the same as in the second plot of trisurf3d_demo2.
-tricontour3d_demo shows the unfilled version of this example.
+The data used is the same as in the second plot of :doc:`trisurf3d_2`.
+:doc:`tricontour3d` shows the unfilled version of this example.
 """
 
 import matplotlib.pyplot as plt
-import matplotlib.tri as tri
 import numpy as np
 
+import matplotlib.tri as tri
+
 # First create the x, y, z coordinates of the points.
 n_angles = 48
 n_radii = 8
@@ -36,8 +37,7 @@ triang.set_mask(np.hypot(x[triang.triangles].mean(axis=1),
                          y[triang.triangles].mean(axis=1))
                 < min_radius)
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 ax.tricontourf(triang, z, cmap=plt.cm.CMRmap)
 
 # Customize the view angle so it's easier to understand the plot.
