@@ -1,21 +1,18 @@
 """
 ==========================================
-3D voxel / volumetric plot with rgb colors
+3D voxel / volumetric plot with RGB colors
 ==========================================
 
-Demonstrates using `Axes3D.voxels` to visualize parts of a color space.
+Demonstrates using `.Axes3D.voxels` to visualize parts of a color space.
 """
 
 import matplotlib.pyplot as plt
 import numpy as np
 
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
-
 
 def midpoints(x):
     sl = ()
-    for i in range(x.ndim):
+    for _ in range(x.ndim):
         x = (x[sl + np.index_exp[:-1]] + x[sl + np.index_exp[1:]]) / 2.0
         sl += np.index_exp[:]
     return x
@@ -36,12 +33,12 @@ colors[..., 1] = gc
 colors[..., 2] = bc
 
 # and plot everything
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 ax.voxels(r, g, b, sphere,
           facecolors=colors,
           edgecolors=np.clip(2*colors - 0.5, 0, 1),  # brighter
           linewidth=0.5)
 ax.set(xlabel='r', ylabel='g', zlabel='b')
+ax.set_aspect('equal')
 
 plt.show()
