@@ -1,15 +1,16 @@
-'''
+"""
 =======================================================
 3D voxel / volumetric plot with cylindrical coordinates
 =======================================================
 
-Demonstrates using the *x*, *y*, *z* arguments of `.Axes3D.voxels`.
-'''
+Demonstrates using the *x*, *y*, *z* parameters of `.Axes3D.voxels`.
+"""
 
 import matplotlib.pyplot as plt
-import matplotlib.colors
 import numpy as np
 
+import matplotlib.colors
+
 
 def midpoints(x):
     sl = ()
@@ -36,8 +37,7 @@ hsv[..., 2] = zc + 0.5
 colors = matplotlib.colors.hsv_to_rgb(hsv)
 
 # and plot everything
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 ax.voxels(x, y, z, sphere,
           facecolors=colors,
           edgecolors=np.clip(2*colors - 0.5, 0, 1),  # brighter
