@@ -8,13 +8,13 @@ Set the special text objects `~.pyplot.title`, `~.pyplot.xlabel`, and
 objects can be placed in the axes using `~.pyplot.text`.
 
 You can use TeX-like mathematical typesetting in all texts; see also
-:doc:`/tutorials/text/mathtext`.
+:ref:`mathtext`.
 
 .. redirect-from:: /gallery/pyplots/pyplot_mathtext
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 t = np.arange(0.0, 2.0, 0.01)
 s = np.sin(2*np.pi*t)
@@ -26,7 +26,7 @@ plt.xlabel('Time [s]')
 plt.ylabel('Voltage [mV]')
 plt.show()
 
-#############################################################################
+# %%
 #
 # .. admonition:: References
 #
