@@ -7,7 +7,7 @@ The Mandelbrot set rendering can be improved by using a normalized recount
 associated with a power normalized colormap (gamma=0.3). Rendering can be
 further enhanced thanks to shading.
 
-The `maxiter` gives the precision of the computation. `maxiter=200` should
+The ``maxiter`` gives the precision of the computation. ``maxiter=200`` should
 take a few seconds on most modern laptops.
 """
 import numpy as np
@@ -29,9 +29,11 @@ def mandelbrot_set(xmin, xmax, ymin, ymax, xn, yn, maxiter, horizon=2.0):
 
 if __name__ == '__main__':
     import time
+
+    import matplotlib.pyplot as plt
+
     import matplotlib
     from matplotlib import colors
-    import matplotlib.pyplot as plt
 
     xmin, xmax, xn = -2.25, +0.75, 3000 // 2
     ymin, ymax, yn = -1.25, +1.25, 2500 // 2
@@ -42,9 +44,9 @@ if __name__ == '__main__':
 
     # Normalized recount as explained in:
     # https://linas.org/art-gallery/escape/smooth.html
-    # https://www.ibm.com/developerworks/community/blogs/jfp/entry/My_Christmas_Gift
+    # https://web.archive.org/web/20160331171238/https://www.ibm.com/developerworks/community/blogs/jfp/entry/My_Christmas_Gift?lang=en
 
-    # This line will generate warnings for null values but it is faster to
+    # This line will generate warnings for null values, but it is faster to
     # process them afterwards using the nan_to_num
     with np.errstate(invalid='ignore'):
         M = np.nan_to_num(N + 1 - np.log2(np.log(abs(Z))) + log_horizon)
@@ -66,7 +68,7 @@ if __name__ == '__main__':
     # Some advertisement for matplotlib
     year = time.strftime("%Y")
     text = ("The Mandelbrot fractal set\n"
-            "Rendered with matplotlib %s, %s - http://matplotlib.org"
+            "Rendered with matplotlib %s, %s - https://matplotlib.org"
             % (matplotlib.__version__, year))
     ax.text(xmin+.025, ymin+.025, text, color="white", fontsize=12, alpha=0.5)
 
