@@ -6,7 +6,7 @@ Solarized Light stylesheet
 This shows an example of "Solarized_Light" styling, which
 tries to replicate the styles of:
 
-- http://ethanschoonover.com/solarized
+- https://ethanschoonover.com/solarized/
 - https://github.com/jrnold/ggthemes
 - http://www.pygal.org/en/stable/documentation/builtin_styles.html#light-solarized
 
@@ -16,13 +16,17 @@ and work of:
 
 using all 8 accents of the color palette - starting with blue
 
-ToDo:
+Still TODO:
 
 - Create alpha values for bar and stacked charts. .33 or .5
 - Apply Layout Rules
 """
 import matplotlib.pyplot as plt
 import numpy as np
+
+# Fixing random state for reproducibility
+np.random.seed(19680801)
+
 x = np.linspace(0, 10)
 with plt.style.context('Solarize_Light2'):
     plt.plot(x, np.sin(x) + x + np.random.randn(50))
