@@ -4,9 +4,9 @@ Embedding in Qt
 ===============
 
 Simple Qt application embedding Matplotlib canvases.  This program will work
-equally well using Qt4 and Qt5.  Either version of Qt can be selected (for
-example) by setting the ``MPLBACKEND`` environment variable to "Qt4Agg" or
-"Qt5Agg", or by first importing the desired version of PyQt.
+equally well using any Qt binding (PyQt6, PySide6, PyQt5, PySide2).  The
+binding can be selected by setting the :envvar:`QT_API` environment variable to
+the binding name, or by first importing it.
 """
 
 import sys
@@ -14,13 +14,10 @@ import time
 
 import numpy as np
 
-from matplotlib.backends.qt_compat import QtCore, QtWidgets, is_pyqt5
-if is_pyqt5():
-    from matplotlib.backends.backend_qt5agg import (
-        FigureCanvas, NavigationToolbar2QT as NavigationToolbar)
-else:
-    from matplotlib.backends.backend_qt4agg import (
-        FigureCanvas, NavigationToolbar2QT as NavigationToolbar)
+from matplotlib.backends.backend_qtagg import FigureCanvas
+from matplotlib.backends.backend_qtagg import \
+    NavigationToolbar2QT as NavigationToolbar
+from matplotlib.backends.qt_compat import QtWidgets
 from matplotlib.figure import Figure
 
 
@@ -32,32 +29,33 @@ class ApplicationWindow(QtWidgets.QMainWindow):
         layout = QtWidgets.QVBoxLayout(self._main)
 
         static_canvas = FigureCanvas(Figure(figsize=(5, 3)))
+        # Ideally one would use self.addToolBar here, but it is slightly
+        # incompatible between PyQt6 and other bindings, so we just add the
+        # toolbar as a plain widget instead.
+        layout.addWidget(NavigationToolbar(static_canvas, self))
         layout.addWidget(static_canvas)
-        self.addToolBar(NavigationToolbar(static_canvas, self))
 
         dynamic_canvas = FigureCanvas(Figure(figsize=(5, 3)))
         layout.addWidget(dynamic_canvas)
-        self.addToolBar(QtCore.Qt.BottomToolBarArea,
-                        NavigationToolbar(dynamic_canvas, self))
+        layout.addWidget(NavigationToolbar(dynamic_canvas, self))
 
         self._static_ax = static_canvas.figure.subplots()
         t = np.linspace(0, 10, 501)
         self._static_ax.plot(t, np.tan(t), ".")
 
         self._dynamic_ax = dynamic_canvas.figure.subplots()
-        self._timer = dynamic_canvas.new_timer(
-            50, [(self._update_canvas, (), {})])
+        t = np.linspace(0, 10, 101)
+        # Set up a Line2D.
+        self._line, = self._dynamic_ax.plot(t, np.sin(t + time.time()))
+        self._timer = dynamic_canvas.new_timer(50)
+        self._timer.add_callback(self._update_canvas)
         self._timer.start()
 
     def _update_canvas(self):
-        self._dynamic_ax.clear()
         t = np.linspace(0, 10, 101)
-        # Use fixed vertical limits to prevent autoscaling changing the scale
-        # of the axis.
-        self._dynamic_ax.set_ylim(-1.1, 1.1)
         # Shift the sinusoid as a function of time.
-        self._dynamic_ax.plot(t, np.sin(t + time.time()))
-        self._dynamic_ax.figure.canvas.draw()
+        self._line.set_data(t, np.sin(t + time.time()))
+        self._line.figure.canvas.draw()
 
 
 if __name__ == "__main__":
@@ -71,4 +69,4 @@ if __name__ == "__main__":
     app.show()
     app.activateWindow()
     app.raise_()
-    qapp.exec_()
+    qapp.exec()
