@@ -1,21 +1,22 @@
 """
 =======================
-Matplotlib With Glade 3
+Matplotlib with Glade 3
 =======================
-
 """
 
-import os
+from pathlib import Path
 
 import gi
+
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 
-from matplotlib.figure import Figure
-from matplotlib.backends.backend_gtk3agg import (
-    FigureCanvasGTK3Agg as FigureCanvas)
 import numpy as np
 
+from matplotlib.backends.backend_gtk3agg import \
+    FigureCanvasGTK3Agg as FigureCanvas
+from matplotlib.figure import Figure
+
 
 class Window1Signals:
     def on_window1_destroy(self, widget):
@@ -24,16 +25,16 @@ class Window1Signals:
 
 def main():
     builder = Gtk.Builder()
-    builder.add_objects_from_file(os.path.join(os.path.dirname(__file__),
-                                               "mpl_with_glade3.glade"),
-                                  ("window1", ""))
+    builder.add_objects_from_file(
+        str(Path(__file__).parent / "mpl_with_glade3.glade"),
+        ("window1", ""))
     builder.connect_signals(Window1Signals())
     window = builder.get_object("window1")
     sw = builder.get_object("scrolledwindow1")
 
     # Start of Matplotlib specific code
     figure = Figure(figsize=(8, 6), dpi=71)
-    axis = figure.add_subplot(111)
+    axis = figure.add_subplot()
     t = np.arange(0.0, 3.0, 0.01)
     s = np.sin(2*np.pi*t)
     axis.plot(t, s)
@@ -43,7 +44,7 @@ def main():
 
     canvas = FigureCanvas(figure)  # a Gtk.DrawingArea
     canvas.set_size_request(800, 600)
-    sw.add_with_viewport(canvas)
+    sw.add(canvas)
     # End of Matplotlib specific code
 
     window.show_all()
