@@ -3,7 +3,7 @@
 GridSpec demo
 =============
 
-This example demonstrates the use of `GridSpec` to generate subplots,
+This example demonstrates the use of `.GridSpec` to generate subplots,
 the control of the relative sizes of subplots with *width_ratios* and
 *height_ratios*, and the control of the spacing around and between subplots
 using subplot params (*left*, *right*, *bottom*, *top*, *wspace*, and
@@ -11,6 +11,7 @@ using subplot params (*left*, *right*, *bottom*, *top*, *wspace*, and
 """
 
 import matplotlib.pyplot as plt
+
 from matplotlib.gridspec import GridSpec
 
 
@@ -31,6 +32,7 @@ ax4 = fig.add_subplot(gs[3])
 
 annotate_axes(fig)
 
+# %%
 
 fig = plt.figure()
 fig.suptitle("Controlling spacing around and between subplots")
