@@ -3,17 +3,15 @@
 Menu
 ====
 
+Using texts to construct a simple menu.
 """
-import numpy as np
-import matplotlib.colors as colors
-import matplotlib.patches as patches
-import matplotlib.mathtext as mathtext
 import matplotlib.pyplot as plt
+
 import matplotlib.artist as artist
-import matplotlib.image as image
+import matplotlib.patches as patches
 
 
-class ItemProperties(object):
+class ItemProperties:
     def __init__(self, fontsize=14, labelcolor='black', bgcolor='yellow',
                  alpha=1.0):
         self.fontsize = fontsize
@@ -21,74 +19,52 @@ class ItemProperties(object):
         self.bgcolor = bgcolor
         self.alpha = alpha
 
-        self.labelcolor_rgb = colors.to_rgba(labelcolor)[:3]
-        self.bgcolor_rgb = colors.to_rgba(bgcolor)[:3]
-
 
 class MenuItem(artist.Artist):
-    parser = mathtext.MathTextParser("Bitmap")
-    padx = 5
-    pady = 5
+    padx = 0.05  # inches
+    pady = 0.05
 
     def __init__(self, fig, labelstr, props=None, hoverprops=None,
                  on_select=None):
-        artist.Artist.__init__(self)
+        super().__init__()
 
         self.set_figure(fig)
         self.labelstr = labelstr
 
-        if props is None:
-            props = ItemProperties()
-
-        if hoverprops is None:
-            hoverprops = ItemProperties()
-
-        self.props = props
-        self.hoverprops = hoverprops
-
-        self.on_select = on_select
-
-        x, self.depth = self.parser.to_mask(
-            labelstr, fontsize=props.fontsize, dpi=fig.dpi)
-
-        if props.fontsize != hoverprops.fontsize:
+        self.props = props if props is not None else ItemProperties()
+        self.hoverprops = (
+            hoverprops if hoverprops is not None else ItemProperties())
+        if self.props.fontsize != self.hoverprops.fontsize:
             raise NotImplementedError(
                 'support for different font sizes not implemented')
 
-        self.labelwidth = x.shape[1]
-        self.labelheight = x.shape[0]
+        self.on_select = on_select
 
-        self.labelArray = np.zeros((x.shape[0], x.shape[1], 4))
-        self.labelArray[:, :, -1] = x/255.
+        # specify coordinates in inches.
+        self.label = fig.text(0, 0, labelstr, transform=fig.dpi_scale_trans,
+                              size=props.fontsize)
+        self.text_bbox = self.label.get_window_extent(
+            fig.canvas.get_renderer())
+        self.text_bbox = fig.dpi_scale_trans.inverted().transform_bbox(self.text_bbox)
 
-        self.label = image.FigureImage(fig, origin='upper')
-        self.label.set_array(self.labelArray)
-
-        # we'll update these later
-        self.rect = patches.Rectangle((0, 0), 1, 1)
+        self.rect = patches.Rectangle(
+            (0, 0), 1, 1, transform=fig.dpi_scale_trans
+        )  # Will be updated later.
 
         self.set_hover_props(False)
 
         fig.canvas.mpl_connect('button_release_event', self.check_select)
 
     def check_select(self, event):
-        over, junk = self.rect.contains(event)
+        over, _ = self.rect.contains(event)
         if not over:
             return
-
         if self.on_select is not None:
             self.on_select(self)
 
-    def set_extent(self, x, y, w, h):
-        print(x, y, w, h)
-        self.rect.set_x(x)
-        self.rect.set_y(y)
-        self.rect.set_width(w)
-        self.rect.set_height(h)
-
-        self.label.ox = x + self.padx
-        self.label.oy = y - self.depth + self.pady/2.
-
+    def set_extent(self, x, y, w, h, depth):
+        self.rect.set(x=x, y=y, width=w, height=h)
+        self.label.set(position=(x + self.padx, y + depth + self.pady / 2))
         self.hover = False
 
     def draw(self, renderer):
@@ -96,55 +72,43 @@ class MenuItem(artist.Artist):
         self.label.draw(renderer)
 
     def set_hover_props(self, b):
-        if b:
-            props = self.hoverprops
-        else:
-            props = self.props
-
-        r, g, b = props.labelcolor_rgb
-        self.labelArray[:, :, 0] = r
-        self.labelArray[:, :, 1] = g
-        self.labelArray[:, :, 2] = b
-        self.label.set_array(self.labelArray)
+        props = self.hoverprops if b else self.props
+        self.label.set(color=props.labelcolor)
         self.rect.set(facecolor=props.bgcolor, alpha=props.alpha)
 
     def set_hover(self, event):
-        'check the hover status of event and return true if status is changed'
-        b, junk = self.rect.contains(event)
-
+        """
+        Update the hover status of event and return whether it was changed.
+        """
+        b, _ = self.rect.contains(event)
         changed = (b != self.hover)
-
         if changed:
             self.set_hover_props(b)
-
         self.hover = b
         return changed
 
 
-class Menu(object):
+class Menu:
     def __init__(self, fig, menuitems):
         self.figure = fig
-        fig.suppressComposite = True
 
         self.menuitems = menuitems
-        self.numitems = len(menuitems)
 
-        maxw = max(item.labelwidth for item in menuitems)
-        maxh = max(item.labelheight for item in menuitems)
+        maxw = max(item.text_bbox.width for item in menuitems)
+        maxh = max(item.text_bbox.height for item in menuitems)
+        depth = max(-item.text_bbox.y0 for item in menuitems)
 
-        totalh = self.numitems*maxh + (self.numitems + 1)*2*MenuItem.pady
+        x0 = 1
+        y0 = 4
 
-        x0 = 100
-        y0 = 400
-
-        width = maxw + 2*MenuItem.padx
+        width = maxw + 2 * MenuItem.padx
         height = maxh + MenuItem.pady
 
         for item in menuitems:
             left = x0
             bottom = y0 - maxh - MenuItem.pady
 
-            item.set_extent(left, bottom, width, height)
+            item.set_extent(left, bottom, width, height, depth)
 
             fig.artists.append(item)
             y0 -= maxh + MenuItem.pady
@@ -152,12 +116,8 @@ class Menu(object):
         fig.canvas.mpl_connect('motion_notify_event', self.on_move)
 
     def on_move(self, event):
-        draw = False
-        for item in self.menuitems:
-            draw = item.set_hover(event)
-            if draw:
-                self.figure.canvas.draw()
-                break
+        if any(item.set_hover(event) for item in self.menuitems):
+            self.figure.canvas.draw()
 
 
 fig = plt.figure()
